tic;    
[VOI, STATES, ALGEBRAIC, CONSTANTS] = mainFunction();
toc;

function [VOI, STATES, ALGEBRAIC, CONSTANTS] = mainFunction()
    % This is the "main function".  In Matlab, things work best if you rename this function to match the filename.
   [VOI, STATES, ALGEBRAIC, CONSTANTS] = solveModel();
end

function [algebraicVariableCount] = getAlgebraicVariableCount()
    % Used later when setting a global variable with the number of algebraic variables.
    % Note: This is not the "main method".
    algebraicVariableCount =233;
end
% There are a total of 44 entries in each of the rate and state variable arrays.
% There are a total of 186 entries in the constant variable array.
%

function [VOI, STATES, ALGEBRAIC, CONSTANTS] = solveModel()
    [LEGEND_STATES, LEGEND_ALGEBRAIC, LEGEND_VOI, LEGEND_CONSTANTS] = createLegends();
    % Create ALGEBRAIC of correct size
    global algebraicVariableCount;  algebraicVariableCount = getAlgebraicVariableCount();
    % Initialise constants and state variables
    [INIT_STATES, CONSTANTS] = initConsts;

    % Set timespan to solve over
    tspan = [0, 1e-1];

    % Set numerical accuracy options for ODE solver
    options = odeset('RelTol', 1e-06, 'AbsTol', 1e-06, 'MaxStep', 1e-3);

    % Solve model with ODE solver
    [VOI, STATES] = ode15s(@(VOI, STATES)computeRates(VOI, STATES, CONSTANTS), tspan, INIT_STATES, options);

    % Compute algebraic variables
    [RATES, ALGEBRAIC] = computeRates(VOI, STATES, CONSTANTS);
    ALGEBRAIC = computeAlgebraic(ALGEBRAIC, CONSTANTS, STATES, VOI);

    vlabels = {'I_pulse in component environment (fA)',...
        'V_m in component environment (volt)',...
        'q_Cai in component environment (fmol)',...
        'q_Ca_TRPN in component environment (fmol)',...
        'tension in component crossbridge_TRPN (N_per_mm2)'};
    [~, i_st, i_alg] = find_indices(vlabels, cellstr(LEGEND_CONSTANTS), cellstr(LEGEND_STATES), cellstr(LEGEND_ALGEBRAIC));
    if i_st
        plot_selected(i_st,VOI,STATES,'s',LEGEND_STATES,'STATES',ceil(sqrt(length(i_st))))
    end
    plot_selected(i_alg,VOI,ALGEBRAIC,'s',LEGEND_ALGEBRAIC,'ALGEBRAIC',ceil(sqrt(length(i_alg))))
end            


function [i_con, i_st, i_alg] = find_indices(labels, LEGEND_CONSTANTS, LEGEND_STATES, LEGEND_ALGEBRAIC)
% return the indices for the selected labels
    all_legends = [LEGEND_CONSTANTS; LEGEND_STATES; LEGEND_ALGEBRAIC];
    
    i_con = [];
    for i = 1:length(labels)
        i_con = [i_con; find(strcmp(labels{i},LEGEND_CONSTANTS))];
    end
    i_st = [];
    for i = 1:length(labels)
        i_st = [i_st; find(strcmp(labels{i},LEGEND_STATES))];
    end
    i_alg = [];
    for i = 1:length(labels)
        i_alg = [i_alg; find(strcmp(labels{i},LEGEND_ALGEBRAIC))];
    end
    
    if length(i_con) + length(i_st) + length(i_alg) < length(labels)
        error('missing index');
    end
end


function [] = plot_selected(ids,x,y,legend_x,legend_y,titlestr,ns)
    istart = 1;
    figure();
%     plot stimuli
    for i = 1:length(ids)
        subplot(ns,ns,i)
        plotting_x = x(istart:end);
        plotting_y = y(istart:end,ids(i));
        if isempty(plotting_y) % probably a constant scalar
            plotting_y = repmat(y(ids(i)),2);
            plotting_x = [x(istart), x(end)];
        end
        plot(plotting_x, plotting_y);
        xlabel('time (s)');
        str = split(legend_y(ids(i),:), ' ');
        str = legend_y(ids(i),:);
        l = legend(str);
        set(l,'interpreter','none');
    end
    suptitle(titlestr)    
end

function [LEGEND_STATES, LEGEND_ALGEBRAIC, LEGEND_VOI, LEGEND_CONSTANTS] = createLegends()
    LEGEND_STATES = ''; LEGEND_ALGEBRAIC = ''; LEGEND_VOI = ''; LEGEND_CONSTANTS = '';
    LEGEND_CONSTANTS(:,1) = strpad('kappa_R_TRPNCa in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,2) = strpad('kappa_R_BU in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,3) = strpad('kappa_R_UW in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,4) = strpad('kappa_R_WS in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,5) = strpad('kappa_R_SU in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,6) = strpad('kappa_LCC_Ca1 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,7) = strpad('kappa_LCC_Ca2 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,8) = strpad('kappa_LCC_K1 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,9) = strpad('kappa_LCC_K2 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,10) = strpad('kappa_d000 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,11) = strpad('kappa_d010 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,12) = strpad('kappa_d020 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,13) = strpad('kappa_d001 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,14) = strpad('kappa_d011 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,15) = strpad('kappa_d021 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,16) = strpad('kappa_f1_000 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,17) = strpad('kappa_f1_100 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,18) = strpad('kappa_f1_001 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,19) = strpad('kappa_f1_101 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,20) = strpad('kappa_f2_000 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,21) = strpad('kappa_f2_100 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,22) = strpad('kappa_f2_001 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,23) = strpad('kappa_f2_101 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,24) = strpad('kappa_f3_010 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,25) = strpad('kappa_f3_110 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,26) = strpad('kappa_f3_011 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,27) = strpad('kappa_f3_111 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,28) = strpad('kappa_fCa000 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,29) = strpad('kappa_fCa100 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,30) = strpad('kappa_fCa010 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,31) = strpad('kappa_fCa110 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,32) = strpad('kappa_fCa020 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,33) = strpad('kappa_fCa120 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,34) = strpad('kappa_PLBph1 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,35) = strpad('kappa_PLBph2 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,36) = strpad('kappa_PLBd1 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,37) = strpad('kappa_PLBd2 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,38) = strpad('kappa_Inh in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,39) = strpad('kappa_RyR in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,40) = strpad('kappa_OC in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,41) = strpad('kappa_CCI in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,42) = strpad('kappa_CII in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,43) = strpad('kappa_IO in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,44) = strpad('kappa_SERCA_R1_2 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,45) = strpad('kappa_SERCA_R2_4 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,46) = strpad('kappa_SERCA_R2_2a in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,47) = strpad('kappa_SERCA_R4_5 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,48) = strpad('kappa_SERCA_R5_6 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,49) = strpad('kappa_SERCA_R6_8 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,50) = strpad('kappa_SERCA_R8_9 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,51) = strpad('kappa_SERCA_R9_10 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,52) = strpad('kappa_SERCA_R10_1 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,53) = strpad('K_TRPN in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,54) = strpad('K_Cai in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,55) = strpad('K_Ca_TRPN in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,56) = strpad('K_B in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,57) = strpad('K_U in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,58) = strpad('K_W in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,59) = strpad('K_S in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,60) = strpad('K_Ca_i in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,61) = strpad('K_Ca_o in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,62) = strpad('K_K_i in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,63) = strpad('K_K_o in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,64) = strpad('K_000_LCC in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,65) = strpad('K_010_LCC in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,66) = strpad('K_020_LCC in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,67) = strpad('K_100_LCC in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,68) = strpad('K_110_LCC in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,69) = strpad('K_120_LCC in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,70) = strpad('K_001_LCC in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,71) = strpad('K_011_LCC in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,72) = strpad('K_021_LCC in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,73) = strpad('K_101_LCC in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,74) = strpad('K_111_LCC in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,75) = strpad('K_121_LCC in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,76) = strpad('K_PLB in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,77) = strpad('K_PKACI in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,78) = strpad('K_PLB_PKACI in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,79) = strpad('K_PP1 in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,80) = strpad('K_PLBp_PP1 in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,81) = strpad('K_PLBp in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,82) = strpad('K_Ip in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,83) = strpad('K_Ip_PP1 in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,84) = strpad('K_Ca_SR in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,85) = strpad('K_C_RyR in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,86) = strpad('K_CI_RyR in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,87) = strpad('K_I_RyR in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,88) = strpad('K_O_RyR in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,89) = strpad('K_P1_SERCA in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,90) = strpad('K_P2_SERCA in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,91) = strpad('K_P2a_SERCA in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,92) = strpad('K_P4_SERCA in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,93) = strpad('K_P5_SERCA in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,94) = strpad('K_P6_SERCA in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,95) = strpad('K_P8_SERCA in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,96) = strpad('K_P9_SERCA in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,97) = strpad('K_P10_SERCA in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,98) = strpad('K_H in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,99) = strpad('K_MgATP in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,100) = strpad('K_MgADP in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,101) = strpad('K_Pi in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,102) = strpad('z_rCa in component BG_parameters (dimensionless)');
    LEGEND_CONSTANTS(:,103) = strpad('z_fd in component BG_parameters (dimensionless)');
    LEGEND_CONSTANTS(:,104) = strpad('z_ff1 in component BG_parameters (dimensionless)');
    LEGEND_CONSTANTS(:,105) = strpad('z_ff2 in component BG_parameters (dimensionless)');
    LEGEND_CONSTANTS(:,106) = strpad('z_ff3 in component BG_parameters (dimensionless)');
    LEGEND_CONSTANTS(:,107) = strpad('z_rd in component BG_parameters (dimensionless)');
    LEGEND_CONSTANTS(:,108) = strpad('z_rf1 in component BG_parameters (dimensionless)');
    LEGEND_CONSTANTS(:,109) = strpad('z_rf2 in component BG_parameters (dimensionless)');
    LEGEND_CONSTANTS(:,110) = strpad('z_rf3 in component BG_parameters (dimensionless)');
    LEGEND_VOI = strpad('time in component environment (second)');
    LEGEND_CONSTANTS(:,111) = strpad('vol_myo in component environment (pL)');
    LEGEND_CONSTANTS(:,112) = strpad('freq in component environment (dimensionless)');
    LEGEND_CONSTANTS(:,113) = strpad('C_m in component environment (fF)');
    LEGEND_CONSTANTS(:,114) = strpad('F in component constants (C_per_mol)');
    LEGEND_STATES(:,1) = strpad('q_membrane in component environment (fC)');
    LEGEND_ALGEBRAIC(:,1) = strpad('V_m in component environment (volt)');
    LEGEND_STATES(:,2) = strpad('q_TRPN in component environment (fmol)');
    LEGEND_STATES(:,3) = strpad('q_Ca_TRPN in component environment (fmol)');
    LEGEND_STATES(:,4) = strpad('q_Cai in component environment (fmol)');
    LEGEND_STATES(:,5) = strpad('q_B in component environment (fmol)');
    LEGEND_STATES(:,6) = strpad('q_U in component environment (fmol)');
    LEGEND_STATES(:,7) = strpad('q_W in component environment (fmol)');
    LEGEND_STATES(:,8) = strpad('q_S in component environment (fmol)');
    LEGEND_STATES(:,9) = strpad('q_Cao in component environment (fmol)');
    LEGEND_STATES(:,10) = strpad('q_Ki in component environment (fmol)');
    LEGEND_STATES(:,11) = strpad('q_Ko in component environment (fmol)');
    LEGEND_STATES(:,12) = strpad('q_PLB in component environment (fmol)');
    LEGEND_STATES(:,13) = strpad('q_PKACI in component environment (fmol)');
    LEGEND_STATES(:,14) = strpad('q_PLB_PKACI in component environment (fmol)');
    LEGEND_STATES(:,15) = strpad('q_PP1 in component environment (fmol)');
    LEGEND_STATES(:,16) = strpad('q_PLBp_PP1 in component environment (fmol)');
    LEGEND_STATES(:,17) = strpad('q_PLBp in component environment (fmol)');
    LEGEND_STATES(:,18) = strpad('q_Ip in component environment (fmol)');
    LEGEND_STATES(:,19) = strpad('q_Ip_PP1 in component environment (fmol)');
    LEGEND_STATES(:,20) = strpad('q_Ca_SR in component environment (fmol)');
    LEGEND_STATES(:,21) = strpad('q_H in component environment (fmol)');
    LEGEND_STATES(:,22) = strpad('q_P in component environment (fmol)');
    LEGEND_STATES(:,23) = strpad('q_MgADP in component environment (fmol)');
    LEGEND_STATES(:,24) = strpad('q_MgATP in component environment (fmol)');
    LEGEND_STATES(:,25) = strpad('q_000_LCC in component environment (fmol)');
    LEGEND_STATES(:,26) = strpad('q_010_LCC in component environment (fmol)');
    LEGEND_STATES(:,27) = strpad('q_020_LCC in component environment (fmol)');
    LEGEND_STATES(:,28) = strpad('q_100_LCC in component environment (fmol)');
    LEGEND_STATES(:,29) = strpad('q_110_LCC in component environment (fmol)');
    LEGEND_STATES(:,30) = strpad('q_120_LCC in component environment (fmol)');
    LEGEND_STATES(:,31) = strpad('q_001_LCC in component environment (fmol)');
    LEGEND_STATES(:,32) = strpad('q_011_LCC in component environment (fmol)');
    LEGEND_STATES(:,33) = strpad('q_021_LCC in component environment (fmol)');
    LEGEND_STATES(:,34) = strpad('q_101_LCC in component environment (fmol)');
    LEGEND_STATES(:,35) = strpad('q_111_LCC in component environment (fmol)');
    LEGEND_STATES(:,36) = strpad('q_121_LCC in component environment (fmol)');
    LEGEND_STATES(:,37) = strpad('q_C_RyR in component environment (fmol)');
    LEGEND_STATES(:,38) = strpad('q_CI_RyR in component environment (fmol)');
    LEGEND_STATES(:,39) = strpad('q_I_RyR in component environment (fmol)');
    LEGEND_STATES(:,40) = strpad('q_O_RyR in component environment (fmol)');
    LEGEND_CONSTANTS(:,115) = strpad('q_P1_SERCA in component environment (fmol)');
    LEGEND_CONSTANTS(:,116) = strpad('q_P2_SERCA in component environment (fmol)');
    LEGEND_CONSTANTS(:,117) = strpad('q_P2a_SERCA in component environment (fmol)');
    LEGEND_CONSTANTS(:,118) = strpad('q_P4_SERCA in component environment (fmol)');
    LEGEND_CONSTANTS(:,119) = strpad('q_P5_SERCA in component environment (fmol)');
    LEGEND_CONSTANTS(:,120) = strpad('q_P6_SERCA in component environment (fmol)');
    LEGEND_CONSTANTS(:,121) = strpad('q_P8_SERCA in component environment (fmol)');
    LEGEND_CONSTANTS(:,122) = strpad('q_P9_SERCA in component environment (fmol)');
    LEGEND_CONSTANTS(:,123) = strpad('q_P10_SERCA in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,233) = strpad('v_R_TRPNCa in component crossbridge_TRPN (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,44) = strpad('v_R_BU in component crossbridge_TRPN (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,47) = strpad('v_R_UW in component crossbridge_TRPN (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,50) = strpad('v_R_WS in component crossbridge_TRPN (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,53) = strpad('v_R_SU in component crossbridge_TRPN (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,230) = strpad('T_total in component crossbridge_TRPN (kPa)');
    LEGEND_STATES(:,41) = strpad('SL in component crossbridge_TRPN (metre)');
    LEGEND_ALGEBRAIC(:,164) = strpad('v_Ca_i_LCC in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,162) = strpad('v_Ca_o_LCC in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,168) = strpad('v_K_i_LCC in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,169) = strpad('v_K_o_LCC in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,170) = strpad('I_mem_LCC in component LCC (fA)');
    LEGEND_ALGEBRAIC(:,45) = strpad('v_PLBph1 in component PLB (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,48) = strpad('v_PLBph2 in component PLB (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,51) = strpad('v_PLBd1 in component PLB (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,54) = strpad('v_PLBd2 in component PLB (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,56) = strpad('v_Inh in component PLB (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,178) = strpad('v_RyR in component RyR (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,183) = strpad('v_RyRgate_Ca_i in component RyR (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,210) = strpad('v_Ca_i_SERCA in component SERCA (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,220) = strpad('v_Ca_SR_SERCA in component SERCA (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,227) = strpad('v_H_SERCA in component SERCA (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,205) = strpad('v_MgADP_SERCA in component SERCA (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,202) = strpad('v_MgATP_SERCA in component SERCA (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,200) = strpad('v_Pi_SERCA in component SERCA (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,10) = strpad('I_pulse in component environment (fA)');
    LEGEND_CONSTANTS(:,124) = strpad('pulse_start in component environment (second)');
    LEGEND_CONSTANTS(:,125) = strpad('pulse_end in component environment (second)');
    LEGEND_CONSTANTS(:,126) = strpad('pulseMag in component environment (fA)');
    LEGEND_CONSTANTS(:,127) = strpad('pulseHolding in component environment (fA)');
    LEGEND_ALGEBRAIC(:,173) = strpad('sum_I in component environment (fA)');
    LEGEND_CONSTANTS(:,128) = strpad('zCa in component ion_valences (dimensionless)');
    LEGEND_CONSTANTS(:,129) = strpad('zK in component ion_valences (dimensionless)');
    LEGEND_ALGEBRAIC(:,3) = strpad('PLB_T in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,4) = strpad('PKACI_T in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,5) = strpad('Ip_T in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,6) = strpad('K_i_T in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,7) = strpad('K_o_T in component environment (fmol)');
    LEGEND_CONSTANTS(:,130) = strpad('R in component constants (J_per_K_per_mol)');
    LEGEND_CONSTANTS(:,131) = strpad('T in component constants (kelvin)');
    LEGEND_CONSTANTS(:,132) = strpad('zNa in component ion_valences (dimensionless)');
    LEGEND_CONSTANTS(:,133) = strpad('zCl in component ion_valences (dimensionless)');
    LEGEND_CONSTANTS(:,134) = strpad('n_Tm in component crossbridge_TRPN (dimensionless)');
    LEGEND_ALGEBRAIC(:,25) = strpad('mu_TRPN in component crossbridge_TRPN (J_per_mol)');
    LEGEND_ALGEBRAIC(:,29) = strpad('mu_Cai in component crossbridge_TRPN (J_per_mol)');
    LEGEND_ALGEBRAIC(:,31) = strpad('mu_Ca_TRPN in component crossbridge_TRPN (J_per_mol)');
    LEGEND_ALGEBRAIC(:,32) = strpad('mu_B in component crossbridge_TRPN (J_per_mol)');
    LEGEND_ALGEBRAIC(:,35) = strpad('mu_U in component crossbridge_TRPN (J_per_mol)');
    LEGEND_ALGEBRAIC(:,38) = strpad('mu_W in component crossbridge_TRPN (J_per_mol)');
    LEGEND_ALGEBRAIC(:,41) = strpad('mu_S in component crossbridge_TRPN (J_per_mol)');
    LEGEND_ALGEBRAIC(:,231) = strpad('tension in component crossbridge_TRPN (N_per_mm2)');
    LEGEND_ALGEBRAIC(:,232) = strpad('mu_tension in component crossbridge_TRPN (J_per_mol)');
    LEGEND_CONSTANTS(:,135) = strpad('kf_coeff in component crossbridge_TRPN (dimensionless)');
    LEGEND_CONSTANTS(:,161) = strpad('n in component crossbridge_TRPN (J_per_mol)');
    LEGEND_CONSTANTS(:,136) = strpad('hh in component crossbridge_TRPN (mm2_per_N)');
    LEGEND_CONSTANTS(:,137) = strpad('SL_0 in component crossbridge_TRPN (metre)');
    LEGEND_CONSTANTS(:,138) = strpad('q_MS in component crossbridge_TRPN (fmol)');
    LEGEND_CONSTANTS(:,139) = strpad('r_s in component crossbridge_TRPN (dimensionless)');
    LEGEND_CONSTANTS(:,140) = strpad('r_w in component crossbridge_TRPN (dimensionless)');
    LEGEND_CONSTANTS(:,141) = strpad('A_eff in component crossbridge_TRPN (dimensionless)');
    LEGEND_CONSTANTS(:,142) = strpad('phi in component crossbridge_TRPN (dimensionless)');
    LEGEND_CONSTANTS(:,143) = strpad('k_uw in component crossbridge_TRPN (per_sec)');
    LEGEND_CONSTANTS(:,144) = strpad('k_ws in component crossbridge_TRPN (per_sec)');
    LEGEND_STATES(:,42) = strpad('G_w in component crossbridge_TRPN (metre)');
    LEGEND_STATES(:,43) = strpad('G_s in component crossbridge_TRPN (metre)');
    LEGEND_CONSTANTS(:,158) = strpad('c_w in component crossbridge_TRPN (per_sec)');
    LEGEND_CONSTANTS(:,159) = strpad('c_s in component crossbridge_TRPN (per_sec)');
    LEGEND_CONSTANTS(:,160) = strpad('A_w in component crossbridge_TRPN (dimensionless)');
    LEGEND_CONSTANTS(:,164) = strpad('A_s in component crossbridge_TRPN (dimensionless)');
    LEGEND_ALGEBRAIC(:,23) = strpad('mu_1 in component crossbridge_TRPN (J_per_m)');
    LEGEND_CONSTANTS(:,165) = strpad('mu_2 in component crossbridge_TRPN (J_per_m)');
    LEGEND_ALGEBRAIC(:,8) = strpad('mu_3 in component crossbridge_TRPN (J_per_m)');
    LEGEND_ALGEBRAIC(:,24) = strpad('mu_4 in component crossbridge_TRPN (J_per_m)');
    LEGEND_CONSTANTS(:,168) = strpad('mu_5 in component crossbridge_TRPN (J_per_m)');
    LEGEND_ALGEBRAIC(:,9) = strpad('mu_6 in component crossbridge_TRPN (J_per_m)');
    LEGEND_ALGEBRAIC(:,27) = strpad('v_1 in component crossbridge_TRPN (m_per_s)');
    LEGEND_CONSTANTS(:,145) = strpad('v_2 in component crossbridge_TRPN (m_per_s)');
    LEGEND_ALGEBRAIC(:,28) = strpad('v_4 in component crossbridge_TRPN (m_per_s)');
    LEGEND_CONSTANTS(:,146) = strpad('v_to_mu in component crossbridge_TRPN (Js_per_m2)');
    LEGEND_ALGEBRAIC(:,43) = strpad('T_active in component crossbridge_TRPN (kPa)');
    LEGEND_CONSTANTS(:,147) = strpad('T_ref in component crossbridge_TRPN (kPa)');
    LEGEND_ALGEBRAIC(:,40) = strpad('mu_T_a in component crossbridge_TRPN (kPa)');
    LEGEND_ALGEBRAIC(:,34) = strpad('mu_T_S in component crossbridge_TRPN (kPa)');
    LEGEND_ALGEBRAIC(:,37) = strpad('mu_T_W in component crossbridge_TRPN (kPa)');
    LEGEND_STATES(:,44) = strpad('Cdd in component crossbridge_TRPN (metre)');
    LEGEND_ALGEBRAIC(:,213) = strpad('eta in component crossbridge_TRPN (per_sec)');
    LEGEND_CONSTANTS(:,148) = strpad('eta_l in component crossbridge_TRPN (per_sec)');
    LEGEND_CONSTANTS(:,149) = strpad('eta_s in component crossbridge_TRPN (per_sec)');
    LEGEND_CONSTANTS(:,150) = strpad('k in component crossbridge_TRPN (dimensionless)');
    LEGEND_CONSTANTS(:,151) = strpad('alpha in component crossbridge_TRPN (kPa)');
    LEGEND_ALGEBRAIC(:,219) = strpad('v_Cdd in component crossbridge_TRPN (m_per_s)');
    LEGEND_ALGEBRAIC(:,214) = strpad('mu_d in component crossbridge_TRPN (J_per_m)');
    LEGEND_ALGEBRAIC(:,215) = strpad('mu_k in component crossbridge_TRPN (J_per_m)');
    LEGEND_ALGEBRAIC(:,216) = strpad('mu_f in component crossbridge_TRPN (J_per_m)');
    LEGEND_ALGEBRAIC(:,223) = strpad('mu_T_passive in component crossbridge_TRPN (kPa)');
    LEGEND_ALGEBRAIC(:,226) = strpad('T_passive in component crossbridge_TRPN (kPa)');
    LEGEND_ALGEBRAIC(:,49) = strpad('mu_Ca_o in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,52) = strpad('mu_Ca_i in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,55) = strpad('mu_K_o in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,57) = strpad('mu_K_i in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,46) = strpad('V_mem in component LCC (volt)');
    LEGEND_ALGEBRAIC(:,66) = strpad('Af_LCC_Ca1 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,98) = strpad('Ar_LCC_Ca1 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,94) = strpad('Am_LCC_Ca1 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,159) = strpad('v_LCC_Ca1 in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,67) = strpad('Af_LCC_Ca2 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,99) = strpad('Ar_LCC_Ca2 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,95) = strpad('Am_LCC_Ca2 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,161) = strpad('v_LCC_Ca2 in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,68) = strpad('Af_LCC_K1 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,100) = strpad('Ar_LCC_K1 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,96) = strpad('Am_LCC_K1 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,163) = strpad('v_LCC_K1 in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,69) = strpad('Af_LCC_K2 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,101) = strpad('Ar_LCC_K2 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,97) = strpad('Am_LCC_K2 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,165) = strpad('v_LCC_K2 in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,88) = strpad('Af_fCa00 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,138) = strpad('Ar_fCa00 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,139) = strpad('v_fCa00 in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,89) = strpad('Af_fCa01 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,140) = strpad('Ar_fCa01 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,143) = strpad('v_fCa01 in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,90) = strpad('Af_fCa02 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,144) = strpad('Ar_fCa02 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,147) = strpad('v_fCa02 in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,91) = strpad('Af_fCa10 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,148) = strpad('Ar_fCa10 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,151) = strpad('v_fCa10 in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,92) = strpad('Af_fCa11 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,152) = strpad('Ar_fCa11 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,155) = strpad('v_fCa11 in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,93) = strpad('Af_fCa12 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,156) = strpad('Ar_fCa12 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,158) = strpad('v_fCa12 in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,58) = strpad('mu_S000_LCC in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,141) = strpad('v_S000_LCC in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,59) = strpad('mu_S010_LCC in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,145) = strpad('v_S010_LCC in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,60) = strpad('mu_S020_LCC in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,149) = strpad('v_S020_LCC in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,61) = strpad('mu_S100_LCC in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,153) = strpad('v_S100_LCC in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,62) = strpad('mu_S110_LCC in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,157) = strpad('v_S110_LCC in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,64) = strpad('mu_S120_LCC in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,160) = strpad('v_S120_LCC in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,11) = strpad('mu_S001_LCC in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,142) = strpad('v_S001_LCC in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,12) = strpad('mu_S011_LCC in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,146) = strpad('v_S011_LCC in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,13) = strpad('mu_S021_LCC in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,150) = strpad('v_S021_LCC in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,14) = strpad('mu_S101_LCC in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,154) = strpad('v_S101_LCC in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,63) = strpad('mu_S111_LCC in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,167) = strpad('v_S111_LCC in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,65) = strpad('mu_S121_LCC in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,172) = strpad('v_S121_LCC in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,70) = strpad('Af_d000 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,102) = strpad('Ar_d000 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,103) = strpad('v_d000 in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,72) = strpad('Af_d010 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,106) = strpad('Ar_d010 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,107) = strpad('v_d010 in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,74) = strpad('Af_d020 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,110) = strpad('Ar_d020 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,111) = strpad('v_d020 in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,76) = strpad('Af_f1_000 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,114) = strpad('Ar_f1_000 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,115) = strpad('v_f1_000 in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,80) = strpad('Af_f2_000 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,122) = strpad('Ar_f2_000 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,123) = strpad('v_f2_000 in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,84) = strpad('Af_f3_010 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,130) = strpad('Ar_f3_010 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,131) = strpad('v_f3_010 in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,78) = strpad('Af_f1_100 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,118) = strpad('Ar_f1_100 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,119) = strpad('v_f1_100 in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,82) = strpad('Af_f2_100 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,126) = strpad('Ar_f2_100 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,127) = strpad('v_f2_100 in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,86) = strpad('Af_f3_110 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,134) = strpad('Ar_f3_110 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,135) = strpad('v_f3_110 in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,71) = strpad('Af_d001 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,104) = strpad('Ar_d001 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,105) = strpad('v_d001 in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,73) = strpad('Af_d011 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,108) = strpad('Ar_d011 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,109) = strpad('v_d011 in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,75) = strpad('Af_d021 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,112) = strpad('Ar_d021 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,113) = strpad('v_d021 in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,77) = strpad('Af_f1_001 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,116) = strpad('Ar_f1_001 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,117) = strpad('v_f1_001 in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,81) = strpad('Af_f2_001 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,124) = strpad('Ar_f2_001 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,125) = strpad('v_f2_001 in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,85) = strpad('Af_f3_011 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,132) = strpad('Ar_f3_011 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,133) = strpad('v_f3_011 in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,79) = strpad('Af_f1_101 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,120) = strpad('Ar_f1_101 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,121) = strpad('v_f1_101 in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,83) = strpad('Af_f2_101 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,128) = strpad('Ar_f2_101 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,129) = strpad('v_f2_101 in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,87) = strpad('Af_f3_111 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,136) = strpad('Ar_f3_111 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,137) = strpad('v_f3_111 in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,2) = strpad('mu_PLB in component PLB (J_per_mol)');
    LEGEND_ALGEBRAIC(:,22) = strpad('mu_PKACI in component PLB (J_per_mol)');
    LEGEND_ALGEBRAIC(:,26) = strpad('mu_PLB_PKACI in component PLB (J_per_mol)');
    LEGEND_ALGEBRAIC(:,30) = strpad('mu_PP1 in component PLB (J_per_mol)');
    LEGEND_ALGEBRAIC(:,33) = strpad('mu_PLBp_PP1 in component PLB (J_per_mol)');
    LEGEND_ALGEBRAIC(:,36) = strpad('mu_PLBp in component PLB (J_per_mol)');
    LEGEND_ALGEBRAIC(:,39) = strpad('mu_Ip in component PLB (J_per_mol)');
    LEGEND_ALGEBRAIC(:,42) = strpad('mu_Ip_PP1 in component PLB (J_per_mol)');
    LEGEND_CONSTANTS(:,152) = strpad('nCa_1 in component RyR (dimensionless)');
    LEGEND_CONSTANTS(:,153) = strpad('nCa_2 in component RyR (dimensionless)');
    LEGEND_ALGEBRAIC(:,166) = strpad('mu_Ca_SR in component RyR (J_per_mol)');
    LEGEND_ALGEBRAIC(:,171) = strpad('mu_Ca_i in component RyR (J_per_mol)');
    LEGEND_ALGEBRAIC(:,15) = strpad('q_Ca_gate_complexes in component RyR (fmol)');
    LEGEND_ALGEBRAIC(:,174) = strpad('mu_C_RyR in component RyR (J_per_mol)');
    LEGEND_ALGEBRAIC(:,175) = strpad('mu_CI_RyR in component RyR (J_per_mol)');
    LEGEND_ALGEBRAIC(:,176) = strpad('mu_I_RyR in component RyR (J_per_mol)');
    LEGEND_ALGEBRAIC(:,177) = strpad('mu_O_RyR in component RyR (J_per_mol)');
    LEGEND_ALGEBRAIC(:,179) = strpad('v_OC in component RyR (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,180) = strpad('v_CCI in component RyR (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,181) = strpad('v_CII in component RyR (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,182) = strpad('v_IO in component RyR (fmol_per_sec)');
    LEGEND_CONSTANTS(:,154) = strpad('n_Ca_i in component SERCA (dimensionless)');
    LEGEND_CONSTANTS(:,155) = strpad('n_Ca_SR in component SERCA (dimensionless)');
    LEGEND_CONSTANTS(:,156) = strpad('n_H in component SERCA (dimensionless)');
    LEGEND_CONSTANTS(:,162) = strpad('q_SERCA_Ca_complexes in component SERCA (fmol)');
    LEGEND_ALGEBRAIC(:,16) = strpad('c_Ca_i in component SERCA (mM)');
    LEGEND_ALGEBRAIC(:,17) = strpad('c_Ca_SR in component SERCA (mM)');
    LEGEND_ALGEBRAIC(:,18) = strpad('c_H in component SERCA (mM)');
    LEGEND_ALGEBRAIC(:,19) = strpad('c_MgADP in component SERCA (mM)');
    LEGEND_ALGEBRAIC(:,20) = strpad('c_MgATP in component SERCA (mM)');
    LEGEND_ALGEBRAIC(:,21) = strpad('c_Pi in component SERCA (mM)');
    LEGEND_CONSTANTS(:,157) = strpad('vol_i in component SERCA (pL)');
    LEGEND_CONSTANTS(:,163) = strpad('vol_sr in component SERCA (pL)');
    LEGEND_CONSTANTS(:,167) = strpad('vol_isr in component SERCA (pL)');
    LEGEND_ALGEBRAIC(:,184) = strpad('mu_Ca_i in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,185) = strpad('mu_Ca_SR in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,186) = strpad('mu_H in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,187) = strpad('mu_MgADP in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,188) = strpad('mu_MgATP in component SERCA (J_per_mol)');
    LEGEND_CONSTANTS(:,166) = strpad('mu_P1 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,204) = strpad('v_P1 in component SERCA (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,189) = strpad('mu_Pi in component SERCA (J_per_mol)');
    LEGEND_CONSTANTS(:,169) = strpad('mu_P2 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,211) = strpad('v_P2 in component SERCA (fmol_per_sec)');
    LEGEND_CONSTANTS(:,170) = strpad('mu_P2a in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,208) = strpad('v_P2a in component SERCA (fmol_per_sec)');
    LEGEND_CONSTANTS(:,171) = strpad('mu_P4 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,217) = strpad('v_P4 in component SERCA (fmol_per_sec)');
    LEGEND_CONSTANTS(:,172) = strpad('mu_P5 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,218) = strpad('v_P5 in component SERCA (fmol_per_sec)');
    LEGEND_CONSTANTS(:,174) = strpad('mu_P6 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,222) = strpad('v_P6 in component SERCA (fmol_per_sec)');
    LEGEND_CONSTANTS(:,175) = strpad('mu_P8 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,225) = strpad('v_P8 in component SERCA (fmol_per_sec)');
    LEGEND_CONSTANTS(:,176) = strpad('mu_P9 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,228) = strpad('v_P9 in component SERCA (fmol_per_sec)');
    LEGEND_CONSTANTS(:,173) = strpad('mu_P10 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,229) = strpad('v_P10 in component SERCA (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,191) = strpad('Af_R1_2 in component SERCA (J_per_mol)');
    LEGEND_CONSTANTS(:,178) = strpad('Ar_R1_2 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,201) = strpad('v_SERCA_R1_2 in component SERCA (fmol_per_sec)');
    LEGEND_CONSTANTS(:,179) = strpad('Af_R5_6 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,192) = strpad('Ar_R5_6 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,203) = strpad('v_SERCA_R5_6 in component SERCA (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,193) = strpad('Af_R2_2a in component SERCA (J_per_mol)');
    LEGEND_CONSTANTS(:,180) = strpad('Ar_R2_2a in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,206) = strpad('v_SERCA_R2_2a in component SERCA (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,194) = strpad('Af_R2_4 in component SERCA (J_per_mol)');
    LEGEND_CONSTANTS(:,181) = strpad('Ar_R2_4 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,207) = strpad('v_SERCA_R2_4 in component SERCA (fmol_per_sec)');
    LEGEND_CONSTANTS(:,182) = strpad('Af_R4_5 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,195) = strpad('Ar_R4_5 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,209) = strpad('v_SERCA_R4_5 in component SERCA (fmol_per_sec)');
    LEGEND_CONSTANTS(:,183) = strpad('Af_R6_8 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,196) = strpad('Ar_R6_8 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,212) = strpad('v_SERCA_R6_8 in component SERCA (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,197) = strpad('Af_R8_9 in component SERCA (J_per_mol)');
    LEGEND_CONSTANTS(:,184) = strpad('Ar_R8_9 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,221) = strpad('v_SERCA_R8_9 in component SERCA (fmol_per_sec)');
    LEGEND_CONSTANTS(:,186) = strpad('Af_R9_10 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,198) = strpad('Ar_R9_10 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,224) = strpad('v_SERCA_R9_10 in component SERCA (fmol_per_sec)');
    LEGEND_CONSTANTS(:,177) = strpad('Af_R10_1 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,190) = strpad('Ar_R10_1 in component SERCA (J_per_mol)');
    LEGEND_ALGEBRAIC(:,199) = strpad('v_SERCA_R10_1 in component SERCA (fmol_per_sec)');
    LEGEND_RATES(:,4) = strpad('d/dt q_Cai in component environment (fmol)');
    LEGEND_RATES(:,2) = strpad('d/dt q_TRPN in component environment (fmol)');
    LEGEND_RATES(:,3) = strpad('d/dt q_Ca_TRPN in component environment (fmol)');
    LEGEND_RATES(:,5) = strpad('d/dt q_B in component environment (fmol)');
    LEGEND_RATES(:,6) = strpad('d/dt q_U in component environment (fmol)');
    LEGEND_RATES(:,7) = strpad('d/dt q_W in component environment (fmol)');
    LEGEND_RATES(:,8) = strpad('d/dt q_S in component environment (fmol)');
    LEGEND_RATES(:,9) = strpad('d/dt q_Cao in component environment (fmol)');
    LEGEND_RATES(:,10) = strpad('d/dt q_Ki in component environment (fmol)');
    LEGEND_RATES(:,11) = strpad('d/dt q_Ko in component environment (fmol)');
    LEGEND_RATES(:,12) = strpad('d/dt q_PLB in component environment (fmol)');
    LEGEND_RATES(:,13) = strpad('d/dt q_PKACI in component environment (fmol)');
    LEGEND_RATES(:,14) = strpad('d/dt q_PLB_PKACI in component environment (fmol)');
    LEGEND_RATES(:,15) = strpad('d/dt q_PP1 in component environment (fmol)');
    LEGEND_RATES(:,16) = strpad('d/dt q_PLBp_PP1 in component environment (fmol)');
    LEGEND_RATES(:,17) = strpad('d/dt q_PLBp in component environment (fmol)');
    LEGEND_RATES(:,18) = strpad('d/dt q_Ip in component environment (fmol)');
    LEGEND_RATES(:,19) = strpad('d/dt q_Ip_PP1 in component environment (fmol)');
    LEGEND_RATES(:,20) = strpad('d/dt q_Ca_SR in component environment (fmol)');
    LEGEND_RATES(:,21) = strpad('d/dt q_H in component environment (fmol)');
    LEGEND_RATES(:,23) = strpad('d/dt q_MgADP in component environment (fmol)');
    LEGEND_RATES(:,24) = strpad('d/dt q_MgATP in component environment (fmol)');
    LEGEND_RATES(:,22) = strpad('d/dt q_P in component environment (fmol)');
    LEGEND_RATES(:,1) = strpad('d/dt q_membrane in component environment (fC)');
    LEGEND_RATES(:,42) = strpad('d/dt G_w in component crossbridge_TRPN (metre)');
    LEGEND_RATES(:,41) = strpad('d/dt SL in component crossbridge_TRPN (metre)');
    LEGEND_RATES(:,43) = strpad('d/dt G_s in component crossbridge_TRPN (metre)');
    LEGEND_RATES(:,44) = strpad('d/dt Cdd in component crossbridge_TRPN (metre)');
    LEGEND_RATES(:,25) = strpad('d/dt q_000_LCC in component environment (fmol)');
    LEGEND_RATES(:,26) = strpad('d/dt q_010_LCC in component environment (fmol)');
    LEGEND_RATES(:,27) = strpad('d/dt q_020_LCC in component environment (fmol)');
    LEGEND_RATES(:,28) = strpad('d/dt q_100_LCC in component environment (fmol)');
    LEGEND_RATES(:,29) = strpad('d/dt q_110_LCC in component environment (fmol)');
    LEGEND_RATES(:,30) = strpad('d/dt q_120_LCC in component environment (fmol)');
    LEGEND_RATES(:,31) = strpad('d/dt q_001_LCC in component environment (fmol)');
    LEGEND_RATES(:,32) = strpad('d/dt q_011_LCC in component environment (fmol)');
    LEGEND_RATES(:,33) = strpad('d/dt q_021_LCC in component environment (fmol)');
    LEGEND_RATES(:,34) = strpad('d/dt q_101_LCC in component environment (fmol)');
    LEGEND_RATES(:,35) = strpad('d/dt q_111_LCC in component environment (fmol)');
    LEGEND_RATES(:,36) = strpad('d/dt q_121_LCC in component environment (fmol)');
    LEGEND_RATES(:,40) = strpad('d/dt q_O_RyR in component environment (fmol)');
    LEGEND_RATES(:,37) = strpad('d/dt q_C_RyR in component environment (fmol)');
    LEGEND_RATES(:,38) = strpad('d/dt q_CI_RyR in component environment (fmol)');
    LEGEND_RATES(:,39) = strpad('d/dt q_I_RyR in component environment (fmol)');
    LEGEND_STATES  = LEGEND_STATES';
    LEGEND_ALGEBRAIC = LEGEND_ALGEBRAIC';
    LEGEND_RATES = LEGEND_RATES';
    LEGEND_CONSTANTS = LEGEND_CONSTANTS';
end

function [STATES, CONSTANTS] = initConsts()
    VOI = 0; CONSTANTS = []; STATES = []; ALGEBRAIC = [];
    CONSTANTS(:,1) = 52.0453;
    CONSTANTS(:,2) = 2.90875;
    CONSTANTS(:,3) = 0.332501;
    CONSTANTS(:,4) = 0.00782356;
    CONSTANTS(:,5) = 140824;
    CONSTANTS(:,6) = 0.756518;
    CONSTANTS(:,7) = 0.996063;
    CONSTANTS(:,8) = 0.0247377;
    CONSTANTS(:,9) = 0.0325707;
    CONSTANTS(:,10) = 329.349;
    CONSTANTS(:,11) = 16.6321;
    CONSTANTS(:,12) = 21.8985;
    CONSTANTS(:,13) = 0.141736;
    CONSTANTS(:,14) = 0.00715766;
    CONSTANTS(:,15) = 0.00942408;
    CONSTANTS(:,16) = 31.7244;
    CONSTANTS(:,17) = 157.535;
    CONSTANTS(:,18) = 0.0136527;
    CONSTANTS(:,19) = 0.0677958;
    CONSTANTS(:,20) = 2.06197;
    CONSTANTS(:,21) = 10.2392;
    CONSTANTS(:,22) = 0.000887375;
    CONSTANTS(:,23) = 0.00440648;
    CONSTANTS(:,24) = 4498.81;
    CONSTANTS(:,25) = 22339.9;
    CONSTANTS(:,26) = 1.93608;
    CONSTANTS(:,27) = 9.61406;
    CONSTANTS(:,28) = 48530.3;
    CONSTANTS(:,29) = 240989;
    CONSTANTS(:,30) = 2450.77;
    CONSTANTS(:,31) = 12169.9;
    CONSTANTS(:,32) = 3226.79;
    CONSTANTS(:,33) = 16023.4;
    CONSTANTS(:,34) = 45.5263;
    CONSTANTS(:,35) = 6.55904;
    CONSTANTS(:,36) = 0.386674;
    CONSTANTS(:,37) = 1.21269;
    CONSTANTS(:,38) = 431.435;
    CONSTANTS(:,39) = 2.85549e+06;
    CONSTANTS(:,40) = 8.83262;
    CONSTANTS(:,41) = 0.12618;
    CONSTANTS(:,42) = 883.262;
    CONSTANTS(:,43) = 73.6052;
    CONSTANTS(:,44) = 1.57289e-05;
    CONSTANTS(:,45) = 175018;
    CONSTANTS(:,46) = 2.44679e+06;
    CONSTANTS(:,47) = 175018;
    CONSTANTS(:,48) = 3487.81;
    CONSTANTS(:,49) = 4.39557e+06;
    CONSTANTS(:,50) = 1.01676e+07;
    CONSTANTS(:,51) = 1.01676e+07;
    CONSTANTS(:,52) = 0.00441447;
    CONSTANTS(:,53) = 1.27424;
    CONSTANTS(:,54) = 1.27424;
    CONSTANTS(:,55) = 0.11171;
    CONSTANTS(:,56) = 6.06164;
    CONSTANTS(:,57) = 2.27312;
    CONSTANTS(:,58) = 14.8627;
    CONSTANTS(:,59) = 3.71567e-06;
    CONSTANTS(:,60) = 0.0343245;
    CONSTANTS(:,61) = 0.227859;
    CONSTANTS(:,62) = 0.000825154;
    CONSTANTS(:,63) = 0.00547767;
    CONSTANTS(:,64) = 1.47795;
    CONSTANTS(:,65) = 29.2665;
    CONSTANTS(:,66) = 22.2281;
    CONSTANTS(:,67) = 0.297629;
    CONSTANTS(:,68) = 5.89367;
    CONSTANTS(:,69) = 4.47629;
    CONSTANTS(:,70) = 3434.28;
    CONSTANTS(:,71) = 68005.7;
    CONSTANTS(:,72) = 51650.9;
    CONSTANTS(:,73) = 691.593;
    CONSTANTS(:,74) = 13695;
    CONSTANTS(:,75) = 10401.4;
    CONSTANTS(:,76) = 0.00235741;
    CONSTANTS(:,77) = 0.395191;
    CONSTANTS(:,78) = 0.638527;
    CONSTANTS(:,79) = 0.361989;
    CONSTANTS(:,80) = 0.203757;
    CONSTANTS(:,81) = 0.326014;
    CONSTANTS(:,82) = 5.41093;
    CONSTANTS(:,83) = 0.0673793;
    CONSTANTS(:,84) = 0.980701;
    CONSTANTS(:,85) = 3962.58;
    CONSTANTS(:,86) = 39.6258;
    CONSTANTS(:,87) = 0.06793;
    CONSTANTS(:,88) = 6.793;
    CONSTANTS(:,89) = 38162.5;
    CONSTANTS(:,90) = 128177;
    CONSTANTS(:,91) = 10585.3;
    CONSTANTS(:,92) = 147985;
    CONSTANTS(:,93) = 0.728251;
    CONSTANTS(:,94) = 29565.2;
    CONSTANTS(:,95) = 4226.28;
    CONSTANTS(:,96) = 2547.31;
    CONSTANTS(:,97) = 4643.82;
    CONSTANTS(:,98) = 212.798;
    CONSTANTS(:,99) = 1254.32;
    CONSTANTS(:,100) = 1.89443e-05;
    CONSTANTS(:,101) = 0.0257106;
    CONSTANTS(:,102) = 2;
    CONSTANTS(:,103) = 2.1404;
    CONSTANTS(:,104) = -1.1495;
    CONSTANTS(:,105) = 0.72162;
    CONSTANTS(:,106) = 4.2933;
    CONSTANTS(:,107) = -2.1404;
    CONSTANTS(:,108) = 1.8993;
    CONSTANTS(:,109) = -0.52288;
    CONSTANTS(:,110) = 0;
    CONSTANTS(:,111) = 34.4;
    CONSTANTS(:,112) = 500;
    CONSTANTS(:,113) = 1.381e5;
    CONSTANTS(:,114) = 96485;
    STATES(:,1) = -13039;
    STATES(:,2) = 2.57;
    STATES(:,3) = 1e-18;
    STATES(:,4) = 6.82e-3;
    STATES(:,5) = 1;
    STATES(:,6) = 0;
    STATES(:,7) = 0;
    STATES(:,8) = 0;
    STATES(:,9) = 6.84;
    STATES(:,10) = 5.51E+03;
    STATES(:,11) = 2.05E+02;
    STATES(:,12) = 4.028E+00;
    STATES(:,13) = 2.234E-03;
    STATES(:,14) = 1e-18;
    STATES(:,15) = 3.382E-02;
    STATES(:,16) = 1e-18;
    STATES(:,17) = 1e-18;
    STATES(:,18) = 1.999E-03;
    STATES(:,19) = 1e-18;
    STATES(:,20) = 0.641;
    STATES(:,21) = 0.004028;
    STATES(:,22) = 570;
    STATES(:,23) = 1.3794;
    STATES(:,24) = 3.8;
    STATES(:,25) = 1.3798e-05;
    STATES(:,26) = 1.3798e-05;
    STATES(:,27) = 1.3798e-05;
    STATES(:,28) = 1.3798e-05;
    STATES(:,29) = 1.3798e-05;
    STATES(:,30) = 1.3798e-05;
    STATES(:,31) = 1.3798e-05;
    STATES(:,32) = 1.3798e-05;
    STATES(:,33) = 1.3798e-05;
    STATES(:,34) = 1.3798e-05;
    STATES(:,35) = 1.3798e-05;
    STATES(:,36) = 1.3798e-05;
    STATES(:,37) = 4.13941e-05;
    STATES(:,38) = 4.13941e-05;
    STATES(:,39) = 4.13941e-05;
    STATES(:,40) = 4.13941e-05;
    CONSTANTS(:,115) = 2.83036e-14;
    CONSTANTS(:,116) = 2.83036e-14;
    CONSTANTS(:,117) = 2.83036e-14;
    CONSTANTS(:,118) = 2.83036e-14;
    CONSTANTS(:,119) = 2.83036e-14;
    CONSTANTS(:,120) = 2.83036e-14;
    CONSTANTS(:,121) = 2.83036e-14;
    CONSTANTS(:,122) = 2.83036e-14;
    CONSTANTS(:,123) = 2.83036e-14;
    STATES(:,41) = 1e-6;
    CONSTANTS(:,124) = 4e-2;
    CONSTANTS(:,125) = 4.1e-2;
    CONSTANTS(:,126) = 1e8;
    CONSTANTS(:,127) = 0;
    CONSTANTS(:,128) = 2;
    CONSTANTS(:,129) = 1;
    CONSTANTS(:,130) = 8.31;
    CONSTANTS(:,131) = 310;
    CONSTANTS(:,132) = 1;
    CONSTANTS(:,133) = -1;
    CONSTANTS(:,134) = 1.1;
    CONSTANTS(:,135) = -0.0118;
    CONSTANTS(:,136) = 1;
    CONSTANTS(:,137) = 2e-6;
    CONSTANTS(:,138) = 1e-6;
    CONSTANTS(:,139) = 0.25;
    CONSTANTS(:,140) = 0.5;
    CONSTANTS(:,141) = 25;
    CONSTANTS(:,142) = 2.23;
    CONSTANTS(:,143) = 26;
    CONSTANTS(:,144) = 4;
    STATES(:,42) = 1e-6;
    STATES(:,43) = 1e-6;
    CONSTANTS(:,145) = 0;
    CONSTANTS(:,146) = 1;
    CONSTANTS(:,147) = 40.5;
    STATES(:,44) = 0;
    CONSTANTS(:,148) = 200e3;
    CONSTANTS(:,149) = 200e3;
    CONSTANTS(:,150) = 7;
    CONSTANTS(:,151) = 2.1;
    CONSTANTS(:,152) = 1;
    CONSTANTS(:,153) = 2;
    CONSTANTS(:,154) = 2;
    CONSTANTS(:,155) = 2;
    CONSTANTS(:,156) = 2;
    CONSTANTS(:,157) = 34.0;
    CONSTANTS(:,158) = ( CONSTANTS(:,142).*CONSTANTS(:,143).*(1.00000 - CONSTANTS(:,140)))./CONSTANTS(:,140);
    CONSTANTS(:,159) = ( CONSTANTS(:,142).*CONSTANTS(:,144).*(1.00000 - CONSTANTS(:,139)).*CONSTANTS(:,140))./CONSTANTS(:,139);
    CONSTANTS(:,160) = ( CONSTANTS(:,141).*CONSTANTS(:,139))./( (1.00000 - CONSTANTS(:,139)).*CONSTANTS(:,140)+CONSTANTS(:,139));
    CONSTANTS(:,161) =  CONSTANTS(:,135).*CONSTANTS(:,130).*CONSTANTS(:,131);
    CONSTANTS(:,162) =  CONSTANTS(:,154).*CONSTANTS(:,118)+ CONSTANTS(:,154).*CONSTANTS(:,119)+ CONSTANTS(:,155).*CONSTANTS(:,120);
    CONSTANTS(:,163) =  CONSTANTS(:,157).*0.0350000;
    CONSTANTS(:,185) = CONSTANTS(:,145);
    CONSTANTS(:,164) = CONSTANTS(:,160);
    CONSTANTS(:,165) =   - CONSTANTS(:,160).*CONSTANTS(:,145).*CONSTANTS(:,146);
    CONSTANTS(:,166) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,89).*CONSTANTS(:,115));
    CONSTANTS(:,167) = CONSTANTS(:,157)+CONSTANTS(:,163);
    CONSTANTS(:,168) =   - CONSTANTS(:,164).*CONSTANTS(:,145).*CONSTANTS(:,146);
    CONSTANTS(:,169) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,90).*CONSTANTS(:,116));
    CONSTANTS(:,170) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,91).*CONSTANTS(:,117));
    CONSTANTS(:,171) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,92).*CONSTANTS(:,118));
    CONSTANTS(:,172) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,93).*CONSTANTS(:,119));
    CONSTANTS(:,173) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,97).*CONSTANTS(:,123));
    CONSTANTS(:,174) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,94).*CONSTANTS(:,120));
    CONSTANTS(:,175) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,95).*CONSTANTS(:,121));
    CONSTANTS(:,176) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,96).*CONSTANTS(:,122));
    CONSTANTS(:,177) = CONSTANTS(:,173);
    CONSTANTS(:,178) = CONSTANTS(:,169);
    CONSTANTS(:,179) = CONSTANTS(:,172);
    CONSTANTS(:,180) = CONSTANTS(:,170);
    CONSTANTS(:,181) = CONSTANTS(:,171);
    CONSTANTS(:,182) = CONSTANTS(:,171);
    CONSTANTS(:,183) = CONSTANTS(:,174);
    CONSTANTS(:,184) = CONSTANTS(:,176);
    CONSTANTS(:,186) = CONSTANTS(:,176);
    if (isempty(STATES)), warning('Initial values for states not set');, end
end

function [RATES, ALGEBRAIC] = computeRates(VOI, STATES, CONSTANTS)
    disp(VOI)
    global algebraicVariableCount;
    statesSize = size(STATES);
    statesColumnCount = statesSize(2);
    if ( statesColumnCount == 1)
        STATES = STATES';
        ALGEBRAIC = zeros(1, algebraicVariableCount);
        utilOnes = 1;
    else
        statesRowCount = statesSize(1);
        ALGEBRAIC = zeros(statesRowCount, algebraicVariableCount);
        RATES = zeros(statesRowCount, statesColumnCount);
        utilOnes = ones(statesRowCount, 1);
    end
    RATES(:,41) = CONSTANTS(:,185);
    ALGEBRAIC(:,8) =  CONSTANTS(:,158).*STATES(:,42).*CONSTANTS(:,146);
    ALGEBRAIC(:,23) =  - CONSTANTS(:,165) - ALGEBRAIC(:,8);
    ALGEBRAIC(:,27) = ALGEBRAIC(:,23)./CONSTANTS(:,146);
    RATES(:,42) = ALGEBRAIC(:,27);
    ALGEBRAIC(:,9) =  CONSTANTS(:,159).*STATES(:,43).*CONSTANTS(:,146);
    ALGEBRAIC(:,24) =  - CONSTANTS(:,168) - ALGEBRAIC(:,9);
    ALGEBRAIC(:,28) = ALGEBRAIC(:,24)./CONSTANTS(:,146);
    RATES(:,43) = ALGEBRAIC(:,28);
    ALGEBRAIC(:,31) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,55).*STATES(:,3));
    ALGEBRAIC(:,32) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,56).*STATES(:,5));
    ALGEBRAIC(:,35) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,57).*STATES(:,6));
    ALGEBRAIC(:,44) =  CONSTANTS(:,2).*(exp((ALGEBRAIC(:,32)+ CONSTANTS(:,134).*ALGEBRAIC(:,31))./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp((ALGEBRAIC(:,35)+ CONSTANTS(:,134).*ALGEBRAIC(:,31))./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    RATES(:,5) =  - ALGEBRAIC(:,44);
    ALGEBRAIC(:,2) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,76).*STATES(:,12));
    ALGEBRAIC(:,22) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,77).*STATES(:,13));
    ALGEBRAIC(:,26) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,78).*STATES(:,14));
    ALGEBRAIC(:,45) =  CONSTANTS(:,34).*(exp((ALGEBRAIC(:,2)+ALGEBRAIC(:,22))./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,26)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,36) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,81).*STATES(:,17));
    ALGEBRAIC(:,48) =  CONSTANTS(:,35).*(exp(ALGEBRAIC(:,26)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp((ALGEBRAIC(:,36)+ALGEBRAIC(:,22))./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    RATES(:,13) = ALGEBRAIC(:,48) - ALGEBRAIC(:,45);
    RATES(:,14) = ALGEBRAIC(:,45) - ALGEBRAIC(:,48);
    ALGEBRAIC(:,38) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,58).*STATES(:,7));
    ALGEBRAIC(:,47) =  CONSTANTS(:,3).*(exp(ALGEBRAIC(:,35)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,38)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,41) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,59).*STATES(:,8));
    ALGEBRAIC(:,50) =  CONSTANTS(:,4).*(exp(ALGEBRAIC(:,38)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,41)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    RATES(:,7) = ALGEBRAIC(:,47) - ALGEBRAIC(:,50);
    ALGEBRAIC(:,30) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,79).*STATES(:,15));
    ALGEBRAIC(:,33) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,80).*STATES(:,16));
    ALGEBRAIC(:,51) =  CONSTANTS(:,36).*(exp((ALGEBRAIC(:,36)+ALGEBRAIC(:,30))./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,33)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    RATES(:,17) = ALGEBRAIC(:,48) - ALGEBRAIC(:,51);
    ALGEBRAIC(:,53) =  CONSTANTS(:,5).*(exp(ALGEBRAIC(:,41)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,35)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    RATES(:,6) = (ALGEBRAIC(:,44) - ALGEBRAIC(:,47))+ALGEBRAIC(:,53);
    RATES(:,8) = ALGEBRAIC(:,50) - ALGEBRAIC(:,53);
    ALGEBRAIC(:,54) =  CONSTANTS(:,37).*(exp(ALGEBRAIC(:,33)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp((ALGEBRAIC(:,2)+ALGEBRAIC(:,30))./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    RATES(:,12) = ALGEBRAIC(:,54) - ALGEBRAIC(:,45);
    RATES(:,16) = ALGEBRAIC(:,51) - ALGEBRAIC(:,54);
    ALGEBRAIC(:,39) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,82).*STATES(:,18));
    ALGEBRAIC(:,42) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,83).*STATES(:,19));
    ALGEBRAIC(:,56) =  CONSTANTS(:,38).*(exp((ALGEBRAIC(:,30)+ALGEBRAIC(:,39))./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,42)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    RATES(:,15) = (ALGEBRAIC(:,54) - ALGEBRAIC(:,51)) - ALGEBRAIC(:,56);
    RATES(:,18) =  - ALGEBRAIC(:,56);
    RATES(:,19) = ALGEBRAIC(:,56);
    ALGEBRAIC(:,58) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,64).*STATES(:,25));
    ALGEBRAIC(:,88) = ALGEBRAIC(:,58);
    ALGEBRAIC(:,52) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,60).*STATES(:,4));
    ALGEBRAIC(:,138) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,70).*STATES(:,31))+ CONSTANTS(:,102).*ALGEBRAIC(:,52);
    ALGEBRAIC(:,139) =  CONSTANTS(:,28).*(exp(ALGEBRAIC(:,88)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,138)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,46) = STATES(:,1)./CONSTANTS(:,113);
    ALGEBRAIC(:,70) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,64).*STATES(:,25))+ CONSTANTS(:,103).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,102) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,67).*STATES(:,28))+ CONSTANTS(:,107).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,103) =  CONSTANTS(:,10).*(exp(ALGEBRAIC(:,70)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,102)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,76) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,64).*STATES(:,25))+ CONSTANTS(:,104).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,114) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,65).*STATES(:,26))+ CONSTANTS(:,108).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,115) =  CONSTANTS(:,16).*(exp(ALGEBRAIC(:,76)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,114)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,80) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,64).*STATES(:,25))+ CONSTANTS(:,105).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,122) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,66).*STATES(:,27))+ CONSTANTS(:,109).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,123) =  CONSTANTS(:,20).*(exp(ALGEBRAIC(:,80)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,122)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,141) = (( - ALGEBRAIC(:,103) - ALGEBRAIC(:,115)) - ALGEBRAIC(:,123)) - ALGEBRAIC(:,139);
    RATES(:,25) = ALGEBRAIC(:,141);
    ALGEBRAIC(:,71) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,70).*STATES(:,31))+ CONSTANTS(:,103).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,104) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,73).*STATES(:,34))+ CONSTANTS(:,107).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,105) =  CONSTANTS(:,13).*(exp(ALGEBRAIC(:,71)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,104)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,77) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,70).*STATES(:,31))+ CONSTANTS(:,104).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,116) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,71).*STATES(:,32))+ CONSTANTS(:,108).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,117) =  CONSTANTS(:,18).*(exp(ALGEBRAIC(:,77)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,116)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,81) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,70).*STATES(:,31))+ CONSTANTS(:,105).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,124) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,72).*STATES(:,33))+ CONSTANTS(:,109).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,125) =  CONSTANTS(:,22).*(exp(ALGEBRAIC(:,81)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,124)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,142) = (( - ALGEBRAIC(:,105) - ALGEBRAIC(:,117)) - ALGEBRAIC(:,125)) -  - ALGEBRAIC(:,139);
    RATES(:,31) = ALGEBRAIC(:,142);
    ALGEBRAIC(:,59) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,65).*STATES(:,26));
    ALGEBRAIC(:,89) = ALGEBRAIC(:,59);
    ALGEBRAIC(:,140) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,71).*STATES(:,32))+ CONSTANTS(:,102).*ALGEBRAIC(:,52);
    ALGEBRAIC(:,143) =  CONSTANTS(:,30).*(exp(ALGEBRAIC(:,89)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,140)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,72) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,65).*STATES(:,26))+ CONSTANTS(:,103).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,106) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,68).*STATES(:,29))+ CONSTANTS(:,107).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,107) =  CONSTANTS(:,11).*(exp(ALGEBRAIC(:,72)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,106)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,84) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,65).*STATES(:,26))+ CONSTANTS(:,106).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,130) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,66).*STATES(:,27))+ CONSTANTS(:,110).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,131) =  CONSTANTS(:,24).*(exp(ALGEBRAIC(:,84)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,130)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,145) = (( - ALGEBRAIC(:,107)+ALGEBRAIC(:,115)) - ALGEBRAIC(:,143)) - ALGEBRAIC(:,131);
    RATES(:,26) = ALGEBRAIC(:,145);
    ALGEBRAIC(:,73) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,71).*STATES(:,32))+ CONSTANTS(:,103).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,108) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,74).*STATES(:,35))+ CONSTANTS(:,107).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,109) =  CONSTANTS(:,14).*(exp(ALGEBRAIC(:,73)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,108)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,85) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,71).*STATES(:,32))+ CONSTANTS(:,106).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,132) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,72).*STATES(:,33))+ CONSTANTS(:,110).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,133) =  CONSTANTS(:,26).*(exp(ALGEBRAIC(:,85)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,132)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,146) = (( - ALGEBRAIC(:,109)+ALGEBRAIC(:,117)) -  - ALGEBRAIC(:,143)) - ALGEBRAIC(:,133);
    RATES(:,32) = ALGEBRAIC(:,146);
    ALGEBRAIC(:,60) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,66).*STATES(:,27));
    ALGEBRAIC(:,90) = ALGEBRAIC(:,60);
    ALGEBRAIC(:,144) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,72).*STATES(:,33))+ CONSTANTS(:,102).*ALGEBRAIC(:,52);
    ALGEBRAIC(:,147) =  CONSTANTS(:,32).*(exp(ALGEBRAIC(:,90)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,144)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,74) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,66).*STATES(:,27))+ CONSTANTS(:,103).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,110) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,69).*STATES(:,30))+ CONSTANTS(:,107).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,111) =  CONSTANTS(:,12).*(exp(ALGEBRAIC(:,74)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,110)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,149) = (( - ALGEBRAIC(:,111)+ALGEBRAIC(:,123)) - ALGEBRAIC(:,147))+ALGEBRAIC(:,131);
    RATES(:,27) = ALGEBRAIC(:,149);
    ALGEBRAIC(:,75) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,72).*STATES(:,33))+ CONSTANTS(:,103).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,112) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,75).*STATES(:,36))+ CONSTANTS(:,107).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,113) =  CONSTANTS(:,15).*(exp(ALGEBRAIC(:,75)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,112)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,150) = (( - ALGEBRAIC(:,113)+ALGEBRAIC(:,125)) -  - ALGEBRAIC(:,147))+ALGEBRAIC(:,133);
    RATES(:,33) = ALGEBRAIC(:,150);
    ALGEBRAIC(:,61) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,67).*STATES(:,28));
    ALGEBRAIC(:,91) = ALGEBRAIC(:,61);
    ALGEBRAIC(:,148) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,73).*STATES(:,34))+ CONSTANTS(:,102).*ALGEBRAIC(:,52);
    ALGEBRAIC(:,151) =  CONSTANTS(:,29).*(exp(ALGEBRAIC(:,91)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,148)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,78) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,67).*STATES(:,28))+ CONSTANTS(:,104).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,118) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,68).*STATES(:,29))+ CONSTANTS(:,108).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,119) =  CONSTANTS(:,17).*(exp(ALGEBRAIC(:,78)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,118)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,82) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,67).*STATES(:,28))+ CONSTANTS(:,105).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,126) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,69).*STATES(:,30))+ CONSTANTS(:,109).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,127) =  CONSTANTS(:,21).*(exp(ALGEBRAIC(:,82)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,126)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,153) = (( - ALGEBRAIC(:,127)+ALGEBRAIC(:,103)) - ALGEBRAIC(:,119)) - ALGEBRAIC(:,151);
    RATES(:,28) = ALGEBRAIC(:,153);
    ALGEBRAIC(:,79) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,73).*STATES(:,34))+ CONSTANTS(:,104).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,120) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,74).*STATES(:,35))+ CONSTANTS(:,108).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,121) =  CONSTANTS(:,19).*(exp(ALGEBRAIC(:,79)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,120)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,83) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,73).*STATES(:,34))+ CONSTANTS(:,105).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,128) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,75).*STATES(:,36))+ CONSTANTS(:,109).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,129) =  CONSTANTS(:,23).*(exp(ALGEBRAIC(:,83)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,128)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,154) = (( - ALGEBRAIC(:,129)+ALGEBRAIC(:,105)) - ALGEBRAIC(:,121)) -  - ALGEBRAIC(:,151);
    RATES(:,34) = ALGEBRAIC(:,154);
    ALGEBRAIC(:,62) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,68).*STATES(:,29));
    ALGEBRAIC(:,92) = ALGEBRAIC(:,62);
    ALGEBRAIC(:,152) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,74).*STATES(:,35))+ CONSTANTS(:,102).*ALGEBRAIC(:,52);
    ALGEBRAIC(:,155) =  CONSTANTS(:,31).*(exp(ALGEBRAIC(:,92)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,152)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,86) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,68).*STATES(:,29))+ CONSTANTS(:,106).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,134) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,69).*STATES(:,30))+ CONSTANTS(:,110).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,135) =  CONSTANTS(:,25).*(exp(ALGEBRAIC(:,86)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,134)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,157) = ((ALGEBRAIC(:,119)+ALGEBRAIC(:,107)) - ALGEBRAIC(:,155)) - ALGEBRAIC(:,135);
    RATES(:,29) = ALGEBRAIC(:,157);
    ALGEBRAIC(:,64) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,69).*STATES(:,30));
    ALGEBRAIC(:,93) = ALGEBRAIC(:,64);
    ALGEBRAIC(:,156) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,75).*STATES(:,36))+ CONSTANTS(:,102).*ALGEBRAIC(:,52);
    ALGEBRAIC(:,158) =  CONSTANTS(:,33).*(exp(ALGEBRAIC(:,93)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,156)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,160) = ((ALGEBRAIC(:,127)+ALGEBRAIC(:,111)) - ALGEBRAIC(:,158))+ALGEBRAIC(:,135);
    RATES(:,30) = ALGEBRAIC(:,160);
    ALGEBRAIC(:,63) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,74).*STATES(:,35));
    ALGEBRAIC(:,66) = ALGEBRAIC(:,52)+ CONSTANTS(:,128).*CONSTANTS(:,114).*ALGEBRAIC(:,46)+ALGEBRAIC(:,63);
    ALGEBRAIC(:,49) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,61).*STATES(:,9));
    ALGEBRAIC(:,98) = ALGEBRAIC(:,49)+ALGEBRAIC(:,63);
    ALGEBRAIC(:,94) =  CONSTANTS(:,128).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,159) = piecewise({ALGEBRAIC(:,94)==0.00000,  CONSTANTS(:,6).*(exp(ALGEBRAIC(:,66)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,98)./( CONSTANTS(:,130).*CONSTANTS(:,131)))) },  ((( CONSTANTS(:,6).*ALGEBRAIC(:,94))./( CONSTANTS(:,130).*CONSTANTS(:,131)))./(exp(ALGEBRAIC(:,94)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - 1.00000)).*(exp(ALGEBRAIC(:,66)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,98)./( CONSTANTS(:,130).*CONSTANTS(:,131)))));
    ALGEBRAIC(:,65) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,75).*STATES(:,36));
    ALGEBRAIC(:,67) = ALGEBRAIC(:,52)+ CONSTANTS(:,128).*CONSTANTS(:,114).*ALGEBRAIC(:,46)+ALGEBRAIC(:,65);
    ALGEBRAIC(:,99) = ALGEBRAIC(:,49)+ALGEBRAIC(:,65);
    ALGEBRAIC(:,95) =  CONSTANTS(:,128).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,161) = piecewise({ALGEBRAIC(:,95)==0.00000,  CONSTANTS(:,7).*(exp(ALGEBRAIC(:,67)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,99)./( CONSTANTS(:,130).*CONSTANTS(:,131)))) },  ((( CONSTANTS(:,7).*ALGEBRAIC(:,95))./( CONSTANTS(:,130).*CONSTANTS(:,131)))./(exp(ALGEBRAIC(:,95)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - 1.00000)).*(exp(ALGEBRAIC(:,67)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,99)./( CONSTANTS(:,130).*CONSTANTS(:,131)))));
    ALGEBRAIC(:,162) = ALGEBRAIC(:,161)+ALGEBRAIC(:,159);
    RATES(:,9) = ALGEBRAIC(:,162);
    ALGEBRAIC(:,57) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,62).*STATES(:,10));
    ALGEBRAIC(:,68) = ALGEBRAIC(:,57)+ CONSTANTS(:,129).*CONSTANTS(:,114).*ALGEBRAIC(:,46)+ALGEBRAIC(:,63);
    ALGEBRAIC(:,55) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,63).*STATES(:,11));
    ALGEBRAIC(:,100) = ALGEBRAIC(:,55)+ALGEBRAIC(:,63);
    ALGEBRAIC(:,96) =  CONSTANTS(:,129).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,163) = piecewise({ALGEBRAIC(:,96)==0.00000,  CONSTANTS(:,8).*(exp(ALGEBRAIC(:,68)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,100)./( CONSTANTS(:,130).*CONSTANTS(:,131)))) },  ((( CONSTANTS(:,8).*ALGEBRAIC(:,96))./( CONSTANTS(:,130).*CONSTANTS(:,131)))./(exp(ALGEBRAIC(:,96)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - 1.00000)).*(exp(ALGEBRAIC(:,68)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,100)./( CONSTANTS(:,130).*CONSTANTS(:,131)))));
    ALGEBRAIC(:,87) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,74).*STATES(:,35))+ CONSTANTS(:,106).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,136) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,75).*STATES(:,36))+ CONSTANTS(:,110).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,137) =  CONSTANTS(:,27).*(exp(ALGEBRAIC(:,87)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,136)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,167) = ((ALGEBRAIC(:,121)+ALGEBRAIC(:,109)) - (((( - ALGEBRAIC(:,155)+ALGEBRAIC(:,159)) - ALGEBRAIC(:,159))+ALGEBRAIC(:,163)) - ALGEBRAIC(:,163))) - ALGEBRAIC(:,137);
    RATES(:,35) = ALGEBRAIC(:,167);
    ALGEBRAIC(:,69) = ALGEBRAIC(:,57)+ CONSTANTS(:,129).*CONSTANTS(:,114).*ALGEBRAIC(:,46)+ALGEBRAIC(:,65);
    ALGEBRAIC(:,101) = ALGEBRAIC(:,55)+ALGEBRAIC(:,65);
    ALGEBRAIC(:,97) =  CONSTANTS(:,129).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,165) = piecewise({ALGEBRAIC(:,97)==0.00000,  CONSTANTS(:,9).*(exp(ALGEBRAIC(:,69)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,101)./( CONSTANTS(:,130).*CONSTANTS(:,131)))) },  ((( CONSTANTS(:,9).*ALGEBRAIC(:,97))./( CONSTANTS(:,130).*CONSTANTS(:,131)))./(exp(ALGEBRAIC(:,97)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - 1.00000)).*(exp(ALGEBRAIC(:,69)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,101)./( CONSTANTS(:,130).*CONSTANTS(:,131)))));
    ALGEBRAIC(:,168) =  - ALGEBRAIC(:,163) - ALGEBRAIC(:,165);
    RATES(:,10) = ALGEBRAIC(:,168);
    ALGEBRAIC(:,169) = ALGEBRAIC(:,165)+ALGEBRAIC(:,163);
    RATES(:,11) = ALGEBRAIC(:,169);
    ALGEBRAIC(:,172) = ((ALGEBRAIC(:,129)+ALGEBRAIC(:,113)) - (((( - ALGEBRAIC(:,158)+ALGEBRAIC(:,161)) - ALGEBRAIC(:,161))+ALGEBRAIC(:,165)) - ALGEBRAIC(:,165)))+ALGEBRAIC(:,137);
    RATES(:,36) = ALGEBRAIC(:,172);
    ALGEBRAIC(:,170) =  CONSTANTS(:,114).*(((((((((((((((((((( CONSTANTS(:,109).*ALGEBRAIC(:,125) -  CONSTANTS(:,105).*ALGEBRAIC(:,125))+ CONSTANTS(:,110).*ALGEBRAIC(:,133) -  CONSTANTS(:,106).*ALGEBRAIC(:,133))+ CONSTANTS(:,108).*ALGEBRAIC(:,121) -  CONSTANTS(:,104).*ALGEBRAIC(:,121))+ CONSTANTS(:,109).*ALGEBRAIC(:,129) -  CONSTANTS(:,105).*ALGEBRAIC(:,129))+ CONSTANTS(:,110).*ALGEBRAIC(:,137) -  CONSTANTS(:,106).*ALGEBRAIC(:,137))+ CONSTANTS(:,108).*ALGEBRAIC(:,117) -  CONSTANTS(:,104).*ALGEBRAIC(:,117))+ CONSTANTS(:,107).*ALGEBRAIC(:,113) -  CONSTANTS(:,103).*ALGEBRAIC(:,113))+ CONSTANTS(:,107).*ALGEBRAIC(:,109) -  CONSTANTS(:,103).*ALGEBRAIC(:,109))+ CONSTANTS(:,107).*ALGEBRAIC(:,105) -  CONSTANTS(:,103).*ALGEBRAIC(:,105))+ CONSTANTS(:,110).*ALGEBRAIC(:,135) -  CONSTANTS(:,106).*ALGEBRAIC(:,135))+ CONSTANTS(:,109).*ALGEBRAIC(:,127) -  CONSTANTS(:,105).*ALGEBRAIC(:,127))+ CONSTANTS(:,108).*ALGEBRAIC(:,119) -  CONSTANTS(:,104).*ALGEBRAIC(:,119))+ CONSTANTS(:,110).*ALGEBRAIC(:,131) -  CONSTANTS(:,106).*ALGEBRAIC(:,131))+ CONSTANTS(:,109).*ALGEBRAIC(:,123) -  CONSTANTS(:,105).*ALGEBRAIC(:,123))+ CONSTANTS(:,108).*ALGEBRAIC(:,115) -  CONSTANTS(:,104).*ALGEBRAIC(:,115))+ CONSTANTS(:,107).*ALGEBRAIC(:,111) -  CONSTANTS(:,103).*ALGEBRAIC(:,111))+ CONSTANTS(:,107).*ALGEBRAIC(:,107) -  CONSTANTS(:,103).*ALGEBRAIC(:,107))+ CONSTANTS(:,107).*ALGEBRAIC(:,103) -  CONSTANTS(:,103).*ALGEBRAIC(:,103)) - ( CONSTANTS(:,128).*ALGEBRAIC(:,159)+ CONSTANTS(:,128).*ALGEBRAIC(:,161))) - ( CONSTANTS(:,129).*ALGEBRAIC(:,163)+ CONSTANTS(:,129).*ALGEBRAIC(:,165)));
    ALGEBRAIC(:,10) = piecewise({VOI>CONSTANTS(:,124)&VOI<CONSTANTS(:,125), CONSTANTS(:,126) }, CONSTANTS(:,127));
    ALGEBRAIC(:,173) =  - ALGEBRAIC(:,170)+ALGEBRAIC(:,10);
    RATES(:,1) = ALGEBRAIC(:,173);
    ALGEBRAIC(:,171) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,60).*STATES(:,4));
    ALGEBRAIC(:,174) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,85).*STATES(:,37));
    ALGEBRAIC(:,177) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,88).*STATES(:,40));
    ALGEBRAIC(:,179) =  CONSTANTS(:,40).*(exp(ALGEBRAIC(:,177)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp((ALGEBRAIC(:,174)+ CONSTANTS(:,153).*ALGEBRAIC(:,171))./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,175) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,86).*STATES(:,38));
    ALGEBRAIC(:,180) =  CONSTANTS(:,41).*(exp((ALGEBRAIC(:,174)+ CONSTANTS(:,152).*ALGEBRAIC(:,171))./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,175)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    RATES(:,37) = ALGEBRAIC(:,179) - ALGEBRAIC(:,180);
    ALGEBRAIC(:,176) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,87).*STATES(:,39));
    ALGEBRAIC(:,181) =  CONSTANTS(:,42).*(exp((ALGEBRAIC(:,175)+ CONSTANTS(:,153).*ALGEBRAIC(:,171))./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,176)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    RATES(:,38) = ALGEBRAIC(:,180) - ALGEBRAIC(:,181);
    ALGEBRAIC(:,182) =  CONSTANTS(:,43).*(exp(ALGEBRAIC(:,176)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp((ALGEBRAIC(:,177)+ CONSTANTS(:,152).*ALGEBRAIC(:,171))./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    RATES(:,40) = ALGEBRAIC(:,182) - ALGEBRAIC(:,179);
    RATES(:,39) = ALGEBRAIC(:,181) - ALGEBRAIC(:,182);
    ALGEBRAIC(:,189) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,101).*STATES(:,22));
    ALGEBRAIC(:,190) = CONSTANTS(:,166)+ALGEBRAIC(:,189);
    ALGEBRAIC(:,199) =  CONSTANTS(:,52).*(exp(CONSTANTS(:,177)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,190)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,200) = ALGEBRAIC(:,199);
    RATES(:,22) = ALGEBRAIC(:,200);
    ALGEBRAIC(:,188) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,99).*STATES(:,24));
    ALGEBRAIC(:,191) = CONSTANTS(:,166)+ALGEBRAIC(:,188);
    ALGEBRAIC(:,201) =  CONSTANTS(:,44).*(exp(ALGEBRAIC(:,191)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(CONSTANTS(:,178)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,202) =  - ALGEBRAIC(:,201);
    RATES(:,24) = ALGEBRAIC(:,202);
    ALGEBRAIC(:,187) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,100).*STATES(:,23));
    ALGEBRAIC(:,192) = ALGEBRAIC(:,187)+CONSTANTS(:,174);
    ALGEBRAIC(:,203) =  CONSTANTS(:,48).*(exp(CONSTANTS(:,179)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,192)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,205) = ALGEBRAIC(:,203);
    RATES(:,23) = ALGEBRAIC(:,205);
    ALGEBRAIC(:,166) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,84).*STATES(:,20));
    ALGEBRAIC(:,178) =  CONSTANTS(:,39).*exp(ALGEBRAIC(:,177)./( CONSTANTS(:,130).*CONSTANTS(:,131))).*(exp(ALGEBRAIC(:,166)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,171)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,185) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,84).*STATES(:,20));
    ALGEBRAIC(:,196) = CONSTANTS(:,175)+ CONSTANTS(:,155).*ALGEBRAIC(:,185);
    ALGEBRAIC(:,212) =  CONSTANTS(:,49).*(exp(CONSTANTS(:,183)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,196)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,220) =  CONSTANTS(:,155).*ALGEBRAIC(:,212);
    RATES(:,20) =  - ALGEBRAIC(:,178)+ALGEBRAIC(:,220);
    [CONSTANTS, STATES, ALGEBRAIC] = rootfind_0(VOI, CONSTANTS, STATES, ALGEBRAIC);
    ALGEBRAIC(:,219) = ALGEBRAIC(:,214)./CONSTANTS(:,146);
    RATES(:,44) = ALGEBRAIC(:,219);
    ALGEBRAIC(:,186) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,98).*STATES(:,21));
    ALGEBRAIC(:,193) = CONSTANTS(:,169)+ALGEBRAIC(:,186);
    ALGEBRAIC(:,206) =  CONSTANTS(:,46).*(exp(ALGEBRAIC(:,193)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(CONSTANTS(:,180)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,195) = CONSTANTS(:,172)+ CONSTANTS(:,156).*ALGEBRAIC(:,186);
    ALGEBRAIC(:,209) =  CONSTANTS(:,47).*(exp(CONSTANTS(:,182)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,195)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,197) = CONSTANTS(:,175)+ CONSTANTS(:,156).*ALGEBRAIC(:,186);
    ALGEBRAIC(:,221) =  CONSTANTS(:,50).*(exp(ALGEBRAIC(:,197)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(CONSTANTS(:,184)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,198) = ALGEBRAIC(:,186)+CONSTANTS(:,173);
    ALGEBRAIC(:,224) =  CONSTANTS(:,51).*(exp(CONSTANTS(:,186)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,198)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,227) = (( CONSTANTS(:,156).*ALGEBRAIC(:,209) - ALGEBRAIC(:,206)) -  CONSTANTS(:,156).*ALGEBRAIC(:,221))+ALGEBRAIC(:,224);
    RATES(:,21) = ALGEBRAIC(:,227);
    ALGEBRAIC(:,25) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,53).*STATES(:,2));
    ALGEBRAIC(:,29) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,60).*STATES(:,4));
    ALGEBRAIC(:,34) =  (CONSTANTS(:,147)./( CONSTANTS(:,137).*CONSTANTS(:,138).*CONSTANTS(:,139))).*STATES(:,8).*(STATES(:,43)+CONSTANTS(:,137));
    ALGEBRAIC(:,37) =  (CONSTANTS(:,147)./( CONSTANTS(:,137).*CONSTANTS(:,138).*CONSTANTS(:,139))).*STATES(:,7).*STATES(:,42);
    ALGEBRAIC(:,40) = ALGEBRAIC(:,34)+ALGEBRAIC(:,37);
    ALGEBRAIC(:,43) = ALGEBRAIC(:,40);
    ALGEBRAIC(:,223) =  (( CONSTANTS(:,151).*ALGEBRAIC(:,213))./CONSTANTS(:,137)).*ALGEBRAIC(:,219);
    ALGEBRAIC(:,226) = ALGEBRAIC(:,223);
    ALGEBRAIC(:,230) = ALGEBRAIC(:,43)+ALGEBRAIC(:,226);
    ALGEBRAIC(:,231) =  ALGEBRAIC(:,230).*1000.00;
    ALGEBRAIC(:,232) =  CONSTANTS(:,136).*CONSTANTS(:,161).*ALGEBRAIC(:,231);
    ALGEBRAIC(:,233) =  CONSTANTS(:,1).*(exp((ALGEBRAIC(:,29)+ALGEBRAIC(:,25))./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp((ALGEBRAIC(:,31)+ALGEBRAIC(:,232))./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,164) = (( (CONSTANTS(:,102)).*ALGEBRAIC(:,151)+ CONSTANTS(:,102).*ALGEBRAIC(:,155)+ CONSTANTS(:,102).*ALGEBRAIC(:,147)+ CONSTANTS(:,102).*ALGEBRAIC(:,143)+ CONSTANTS(:,102).*ALGEBRAIC(:,139)+ CONSTANTS(:,102).*ALGEBRAIC(:,158)) - ALGEBRAIC(:,159)) - ALGEBRAIC(:,161);
    ALGEBRAIC(:,183) = (( CONSTANTS(:,153).*ALGEBRAIC(:,179) -  CONSTANTS(:,152).*ALGEBRAIC(:,180)) -  CONSTANTS(:,153).*ALGEBRAIC(:,181))+ CONSTANTS(:,152).*ALGEBRAIC(:,182);
    ALGEBRAIC(:,184) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,60).*STATES(:,4));
    ALGEBRAIC(:,194) = CONSTANTS(:,169)+ CONSTANTS(:,154).*ALGEBRAIC(:,184);
    ALGEBRAIC(:,207) =  CONSTANTS(:,45).*(exp(ALGEBRAIC(:,194)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(CONSTANTS(:,181)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,210) =   - CONSTANTS(:,154).*ALGEBRAIC(:,207);
    RATES(:,4) =  - ALGEBRAIC(:,233)+ALGEBRAIC(:,164)+ALGEBRAIC(:,178)+ALGEBRAIC(:,183)+ALGEBRAIC(:,210);
    RATES(:,2) =  - ALGEBRAIC(:,233);
    RATES(:,3) = ALGEBRAIC(:,233);
   RATES = RATES';
end

% Calculate algebraic variables
function ALGEBRAIC = computeAlgebraic(ALGEBRAIC, CONSTANTS, STATES, VOI)
    statesSize = size(STATES);
    statesColumnCount = statesSize(2);
    if ( statesColumnCount == 1)
        STATES = STATES';
        utilOnes = 1;
    else
        statesRowCount = statesSize(1);
        utilOnes = ones(statesRowCount, 1);
    end
    ALGEBRAIC(:,8) =  CONSTANTS(:,158).*STATES(:,42).*CONSTANTS(:,146);
    ALGEBRAIC(:,23) =  - CONSTANTS(:,165) - ALGEBRAIC(:,8);
    ALGEBRAIC(:,27) = ALGEBRAIC(:,23)./CONSTANTS(:,146);
    ALGEBRAIC(:,9) =  CONSTANTS(:,159).*STATES(:,43).*CONSTANTS(:,146);
    ALGEBRAIC(:,24) =  - CONSTANTS(:,168) - ALGEBRAIC(:,9);
    ALGEBRAIC(:,28) = ALGEBRAIC(:,24)./CONSTANTS(:,146);
    ALGEBRAIC(:,31) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,55).*STATES(:,3));
    ALGEBRAIC(:,32) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,56).*STATES(:,5));
    ALGEBRAIC(:,35) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,57).*STATES(:,6));
    ALGEBRAIC(:,44) =  CONSTANTS(:,2).*(exp((ALGEBRAIC(:,32)+ CONSTANTS(:,134).*ALGEBRAIC(:,31))./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp((ALGEBRAIC(:,35)+ CONSTANTS(:,134).*ALGEBRAIC(:,31))./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,2) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,76).*STATES(:,12));
    ALGEBRAIC(:,22) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,77).*STATES(:,13));
    ALGEBRAIC(:,26) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,78).*STATES(:,14));
    ALGEBRAIC(:,45) =  CONSTANTS(:,34).*(exp((ALGEBRAIC(:,2)+ALGEBRAIC(:,22))./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,26)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,36) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,81).*STATES(:,17));
    ALGEBRAIC(:,48) =  CONSTANTS(:,35).*(exp(ALGEBRAIC(:,26)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp((ALGEBRAIC(:,36)+ALGEBRAIC(:,22))./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,38) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,58).*STATES(:,7));
    ALGEBRAIC(:,47) =  CONSTANTS(:,3).*(exp(ALGEBRAIC(:,35)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,38)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,41) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,59).*STATES(:,8));
    ALGEBRAIC(:,50) =  CONSTANTS(:,4).*(exp(ALGEBRAIC(:,38)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,41)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,30) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,79).*STATES(:,15));
    ALGEBRAIC(:,33) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,80).*STATES(:,16));
    ALGEBRAIC(:,51) =  CONSTANTS(:,36).*(exp((ALGEBRAIC(:,36)+ALGEBRAIC(:,30))./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,33)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,53) =  CONSTANTS(:,5).*(exp(ALGEBRAIC(:,41)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,35)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,54) =  CONSTANTS(:,37).*(exp(ALGEBRAIC(:,33)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp((ALGEBRAIC(:,2)+ALGEBRAIC(:,30))./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,39) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,82).*STATES(:,18));
    ALGEBRAIC(:,42) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,83).*STATES(:,19));
    ALGEBRAIC(:,56) =  CONSTANTS(:,38).*(exp((ALGEBRAIC(:,30)+ALGEBRAIC(:,39))./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,42)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,58) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,64).*STATES(:,25));
    ALGEBRAIC(:,88) = ALGEBRAIC(:,58);
    ALGEBRAIC(:,52) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,60).*STATES(:,4));
    ALGEBRAIC(:,138) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,70).*STATES(:,31))+ CONSTANTS(:,102).*ALGEBRAIC(:,52);
    ALGEBRAIC(:,139) =  CONSTANTS(:,28).*(exp(ALGEBRAIC(:,88)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,138)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,46) = STATES(:,1)./CONSTANTS(:,113);
    ALGEBRAIC(:,70) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,64).*STATES(:,25))+ CONSTANTS(:,103).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,102) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,67).*STATES(:,28))+ CONSTANTS(:,107).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,103) =  CONSTANTS(:,10).*(exp(ALGEBRAIC(:,70)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,102)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,76) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,64).*STATES(:,25))+ CONSTANTS(:,104).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,114) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,65).*STATES(:,26))+ CONSTANTS(:,108).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,115) =  CONSTANTS(:,16).*(exp(ALGEBRAIC(:,76)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,114)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,80) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,64).*STATES(:,25))+ CONSTANTS(:,105).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,122) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,66).*STATES(:,27))+ CONSTANTS(:,109).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,123) =  CONSTANTS(:,20).*(exp(ALGEBRAIC(:,80)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,122)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,141) = (( - ALGEBRAIC(:,103) - ALGEBRAIC(:,115)) - ALGEBRAIC(:,123)) - ALGEBRAIC(:,139);
    ALGEBRAIC(:,71) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,70).*STATES(:,31))+ CONSTANTS(:,103).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,104) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,73).*STATES(:,34))+ CONSTANTS(:,107).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,105) =  CONSTANTS(:,13).*(exp(ALGEBRAIC(:,71)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,104)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,77) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,70).*STATES(:,31))+ CONSTANTS(:,104).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,116) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,71).*STATES(:,32))+ CONSTANTS(:,108).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,117) =  CONSTANTS(:,18).*(exp(ALGEBRAIC(:,77)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,116)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,81) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,70).*STATES(:,31))+ CONSTANTS(:,105).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,124) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,72).*STATES(:,33))+ CONSTANTS(:,109).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,125) =  CONSTANTS(:,22).*(exp(ALGEBRAIC(:,81)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,124)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,142) = (( - ALGEBRAIC(:,105) - ALGEBRAIC(:,117)) - ALGEBRAIC(:,125)) -  - ALGEBRAIC(:,139);
    ALGEBRAIC(:,59) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,65).*STATES(:,26));
    ALGEBRAIC(:,89) = ALGEBRAIC(:,59);
    ALGEBRAIC(:,140) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,71).*STATES(:,32))+ CONSTANTS(:,102).*ALGEBRAIC(:,52);
    ALGEBRAIC(:,143) =  CONSTANTS(:,30).*(exp(ALGEBRAIC(:,89)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,140)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,72) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,65).*STATES(:,26))+ CONSTANTS(:,103).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,106) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,68).*STATES(:,29))+ CONSTANTS(:,107).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,107) =  CONSTANTS(:,11).*(exp(ALGEBRAIC(:,72)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,106)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,84) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,65).*STATES(:,26))+ CONSTANTS(:,106).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,130) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,66).*STATES(:,27))+ CONSTANTS(:,110).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,131) =  CONSTANTS(:,24).*(exp(ALGEBRAIC(:,84)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,130)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,145) = (( - ALGEBRAIC(:,107)+ALGEBRAIC(:,115)) - ALGEBRAIC(:,143)) - ALGEBRAIC(:,131);
    ALGEBRAIC(:,73) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,71).*STATES(:,32))+ CONSTANTS(:,103).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,108) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,74).*STATES(:,35))+ CONSTANTS(:,107).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,109) =  CONSTANTS(:,14).*(exp(ALGEBRAIC(:,73)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,108)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,85) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,71).*STATES(:,32))+ CONSTANTS(:,106).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,132) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,72).*STATES(:,33))+ CONSTANTS(:,110).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,133) =  CONSTANTS(:,26).*(exp(ALGEBRAIC(:,85)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,132)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,146) = (( - ALGEBRAIC(:,109)+ALGEBRAIC(:,117)) -  - ALGEBRAIC(:,143)) - ALGEBRAIC(:,133);
    ALGEBRAIC(:,60) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,66).*STATES(:,27));
    ALGEBRAIC(:,90) = ALGEBRAIC(:,60);
    ALGEBRAIC(:,144) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,72).*STATES(:,33))+ CONSTANTS(:,102).*ALGEBRAIC(:,52);
    ALGEBRAIC(:,147) =  CONSTANTS(:,32).*(exp(ALGEBRAIC(:,90)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,144)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,74) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,66).*STATES(:,27))+ CONSTANTS(:,103).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,110) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,69).*STATES(:,30))+ CONSTANTS(:,107).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,111) =  CONSTANTS(:,12).*(exp(ALGEBRAIC(:,74)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,110)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,149) = (( - ALGEBRAIC(:,111)+ALGEBRAIC(:,123)) - ALGEBRAIC(:,147))+ALGEBRAIC(:,131);
    ALGEBRAIC(:,75) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,72).*STATES(:,33))+ CONSTANTS(:,103).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,112) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,75).*STATES(:,36))+ CONSTANTS(:,107).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,113) =  CONSTANTS(:,15).*(exp(ALGEBRAIC(:,75)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,112)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,150) = (( - ALGEBRAIC(:,113)+ALGEBRAIC(:,125)) -  - ALGEBRAIC(:,147))+ALGEBRAIC(:,133);
    ALGEBRAIC(:,61) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,67).*STATES(:,28));
    ALGEBRAIC(:,91) = ALGEBRAIC(:,61);
    ALGEBRAIC(:,148) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,73).*STATES(:,34))+ CONSTANTS(:,102).*ALGEBRAIC(:,52);
    ALGEBRAIC(:,151) =  CONSTANTS(:,29).*(exp(ALGEBRAIC(:,91)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,148)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,78) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,67).*STATES(:,28))+ CONSTANTS(:,104).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,118) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,68).*STATES(:,29))+ CONSTANTS(:,108).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,119) =  CONSTANTS(:,17).*(exp(ALGEBRAIC(:,78)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,118)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,82) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,67).*STATES(:,28))+ CONSTANTS(:,105).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,126) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,69).*STATES(:,30))+ CONSTANTS(:,109).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,127) =  CONSTANTS(:,21).*(exp(ALGEBRAIC(:,82)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,126)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,153) = (( - ALGEBRAIC(:,127)+ALGEBRAIC(:,103)) - ALGEBRAIC(:,119)) - ALGEBRAIC(:,151);
    ALGEBRAIC(:,79) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,73).*STATES(:,34))+ CONSTANTS(:,104).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,120) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,74).*STATES(:,35))+ CONSTANTS(:,108).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,121) =  CONSTANTS(:,19).*(exp(ALGEBRAIC(:,79)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,120)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,83) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,73).*STATES(:,34))+ CONSTANTS(:,105).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,128) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,75).*STATES(:,36))+ CONSTANTS(:,109).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,129) =  CONSTANTS(:,23).*(exp(ALGEBRAIC(:,83)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,128)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,154) = (( - ALGEBRAIC(:,129)+ALGEBRAIC(:,105)) - ALGEBRAIC(:,121)) -  - ALGEBRAIC(:,151);
    ALGEBRAIC(:,62) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,68).*STATES(:,29));
    ALGEBRAIC(:,92) = ALGEBRAIC(:,62);
    ALGEBRAIC(:,152) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,74).*STATES(:,35))+ CONSTANTS(:,102).*ALGEBRAIC(:,52);
    ALGEBRAIC(:,155) =  CONSTANTS(:,31).*(exp(ALGEBRAIC(:,92)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,152)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,86) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,68).*STATES(:,29))+ CONSTANTS(:,106).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,134) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,69).*STATES(:,30))+ CONSTANTS(:,110).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,135) =  CONSTANTS(:,25).*(exp(ALGEBRAIC(:,86)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,134)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,157) = ((ALGEBRAIC(:,119)+ALGEBRAIC(:,107)) - ALGEBRAIC(:,155)) - ALGEBRAIC(:,135);
    ALGEBRAIC(:,64) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,69).*STATES(:,30));
    ALGEBRAIC(:,93) = ALGEBRAIC(:,64);
    ALGEBRAIC(:,156) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,75).*STATES(:,36))+ CONSTANTS(:,102).*ALGEBRAIC(:,52);
    ALGEBRAIC(:,158) =  CONSTANTS(:,33).*(exp(ALGEBRAIC(:,93)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,156)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,160) = ((ALGEBRAIC(:,127)+ALGEBRAIC(:,111)) - ALGEBRAIC(:,158))+ALGEBRAIC(:,135);
    ALGEBRAIC(:,63) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,74).*STATES(:,35));
    ALGEBRAIC(:,66) = ALGEBRAIC(:,52)+ CONSTANTS(:,128).*CONSTANTS(:,114).*ALGEBRAIC(:,46)+ALGEBRAIC(:,63);
    ALGEBRAIC(:,49) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,61).*STATES(:,9));
    ALGEBRAIC(:,98) = ALGEBRAIC(:,49)+ALGEBRAIC(:,63);
    ALGEBRAIC(:,94) =  CONSTANTS(:,128).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,159) = piecewise({ALGEBRAIC(:,94)==0.00000,  CONSTANTS(:,6).*(exp(ALGEBRAIC(:,66)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,98)./( CONSTANTS(:,130).*CONSTANTS(:,131)))) },  ((( CONSTANTS(:,6).*ALGEBRAIC(:,94))./( CONSTANTS(:,130).*CONSTANTS(:,131)))./(exp(ALGEBRAIC(:,94)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - 1.00000)).*(exp(ALGEBRAIC(:,66)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,98)./( CONSTANTS(:,130).*CONSTANTS(:,131)))));
    ALGEBRAIC(:,65) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,75).*STATES(:,36));
    ALGEBRAIC(:,67) = ALGEBRAIC(:,52)+ CONSTANTS(:,128).*CONSTANTS(:,114).*ALGEBRAIC(:,46)+ALGEBRAIC(:,65);
    ALGEBRAIC(:,99) = ALGEBRAIC(:,49)+ALGEBRAIC(:,65);
    ALGEBRAIC(:,95) =  CONSTANTS(:,128).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,161) = piecewise({ALGEBRAIC(:,95)==0.00000,  CONSTANTS(:,7).*(exp(ALGEBRAIC(:,67)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,99)./( CONSTANTS(:,130).*CONSTANTS(:,131)))) },  ((( CONSTANTS(:,7).*ALGEBRAIC(:,95))./( CONSTANTS(:,130).*CONSTANTS(:,131)))./(exp(ALGEBRAIC(:,95)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - 1.00000)).*(exp(ALGEBRAIC(:,67)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,99)./( CONSTANTS(:,130).*CONSTANTS(:,131)))));
    ALGEBRAIC(:,162) = ALGEBRAIC(:,161)+ALGEBRAIC(:,159);
    ALGEBRAIC(:,57) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,62).*STATES(:,10));
    ALGEBRAIC(:,68) = ALGEBRAIC(:,57)+ CONSTANTS(:,129).*CONSTANTS(:,114).*ALGEBRAIC(:,46)+ALGEBRAIC(:,63);
    ALGEBRAIC(:,55) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,63).*STATES(:,11));
    ALGEBRAIC(:,100) = ALGEBRAIC(:,55)+ALGEBRAIC(:,63);
    ALGEBRAIC(:,96) =  CONSTANTS(:,129).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,163) = piecewise({ALGEBRAIC(:,96)==0.00000,  CONSTANTS(:,8).*(exp(ALGEBRAIC(:,68)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,100)./( CONSTANTS(:,130).*CONSTANTS(:,131)))) },  ((( CONSTANTS(:,8).*ALGEBRAIC(:,96))./( CONSTANTS(:,130).*CONSTANTS(:,131)))./(exp(ALGEBRAIC(:,96)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - 1.00000)).*(exp(ALGEBRAIC(:,68)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,100)./( CONSTANTS(:,130).*CONSTANTS(:,131)))));
    ALGEBRAIC(:,87) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,74).*STATES(:,35))+ CONSTANTS(:,106).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,136) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,75).*STATES(:,36))+ CONSTANTS(:,110).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,137) =  CONSTANTS(:,27).*(exp(ALGEBRAIC(:,87)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,136)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,167) = ((ALGEBRAIC(:,121)+ALGEBRAIC(:,109)) - (((( - ALGEBRAIC(:,155)+ALGEBRAIC(:,159)) - ALGEBRAIC(:,159))+ALGEBRAIC(:,163)) - ALGEBRAIC(:,163))) - ALGEBRAIC(:,137);
    ALGEBRAIC(:,69) = ALGEBRAIC(:,57)+ CONSTANTS(:,129).*CONSTANTS(:,114).*ALGEBRAIC(:,46)+ALGEBRAIC(:,65);
    ALGEBRAIC(:,101) = ALGEBRAIC(:,55)+ALGEBRAIC(:,65);
    ALGEBRAIC(:,97) =  CONSTANTS(:,129).*CONSTANTS(:,114).*ALGEBRAIC(:,46);
    ALGEBRAIC(:,165) = piecewise({ALGEBRAIC(:,97)==0.00000,  CONSTANTS(:,9).*(exp(ALGEBRAIC(:,69)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,101)./( CONSTANTS(:,130).*CONSTANTS(:,131)))) },  ((( CONSTANTS(:,9).*ALGEBRAIC(:,97))./( CONSTANTS(:,130).*CONSTANTS(:,131)))./(exp(ALGEBRAIC(:,97)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - 1.00000)).*(exp(ALGEBRAIC(:,69)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,101)./( CONSTANTS(:,130).*CONSTANTS(:,131)))));
    ALGEBRAIC(:,168) =  - ALGEBRAIC(:,163) - ALGEBRAIC(:,165);
    ALGEBRAIC(:,169) = ALGEBRAIC(:,165)+ALGEBRAIC(:,163);
    ALGEBRAIC(:,172) = ((ALGEBRAIC(:,129)+ALGEBRAIC(:,113)) - (((( - ALGEBRAIC(:,158)+ALGEBRAIC(:,161)) - ALGEBRAIC(:,161))+ALGEBRAIC(:,165)) - ALGEBRAIC(:,165)))+ALGEBRAIC(:,137);
    ALGEBRAIC(:,170) =  CONSTANTS(:,114).*(((((((((((((((((((( CONSTANTS(:,109).*ALGEBRAIC(:,125) -  CONSTANTS(:,105).*ALGEBRAIC(:,125))+ CONSTANTS(:,110).*ALGEBRAIC(:,133) -  CONSTANTS(:,106).*ALGEBRAIC(:,133))+ CONSTANTS(:,108).*ALGEBRAIC(:,121) -  CONSTANTS(:,104).*ALGEBRAIC(:,121))+ CONSTANTS(:,109).*ALGEBRAIC(:,129) -  CONSTANTS(:,105).*ALGEBRAIC(:,129))+ CONSTANTS(:,110).*ALGEBRAIC(:,137) -  CONSTANTS(:,106).*ALGEBRAIC(:,137))+ CONSTANTS(:,108).*ALGEBRAIC(:,117) -  CONSTANTS(:,104).*ALGEBRAIC(:,117))+ CONSTANTS(:,107).*ALGEBRAIC(:,113) -  CONSTANTS(:,103).*ALGEBRAIC(:,113))+ CONSTANTS(:,107).*ALGEBRAIC(:,109) -  CONSTANTS(:,103).*ALGEBRAIC(:,109))+ CONSTANTS(:,107).*ALGEBRAIC(:,105) -  CONSTANTS(:,103).*ALGEBRAIC(:,105))+ CONSTANTS(:,110).*ALGEBRAIC(:,135) -  CONSTANTS(:,106).*ALGEBRAIC(:,135))+ CONSTANTS(:,109).*ALGEBRAIC(:,127) -  CONSTANTS(:,105).*ALGEBRAIC(:,127))+ CONSTANTS(:,108).*ALGEBRAIC(:,119) -  CONSTANTS(:,104).*ALGEBRAIC(:,119))+ CONSTANTS(:,110).*ALGEBRAIC(:,131) -  CONSTANTS(:,106).*ALGEBRAIC(:,131))+ CONSTANTS(:,109).*ALGEBRAIC(:,123) -  CONSTANTS(:,105).*ALGEBRAIC(:,123))+ CONSTANTS(:,108).*ALGEBRAIC(:,115) -  CONSTANTS(:,104).*ALGEBRAIC(:,115))+ CONSTANTS(:,107).*ALGEBRAIC(:,111) -  CONSTANTS(:,103).*ALGEBRAIC(:,111))+ CONSTANTS(:,107).*ALGEBRAIC(:,107) -  CONSTANTS(:,103).*ALGEBRAIC(:,107))+ CONSTANTS(:,107).*ALGEBRAIC(:,103) -  CONSTANTS(:,103).*ALGEBRAIC(:,103)) - ( CONSTANTS(:,128).*ALGEBRAIC(:,159)+ CONSTANTS(:,128).*ALGEBRAIC(:,161))) - ( CONSTANTS(:,129).*ALGEBRAIC(:,163)+ CONSTANTS(:,129).*ALGEBRAIC(:,165)));
    ALGEBRAIC(:,10) = piecewise({VOI>CONSTANTS(:,124)&VOI<CONSTANTS(:,125), CONSTANTS(:,126) }, CONSTANTS(:,127));
    ALGEBRAIC(:,173) =  - ALGEBRAIC(:,170)+ALGEBRAIC(:,10);
    ALGEBRAIC(:,171) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,60).*STATES(:,4));
    ALGEBRAIC(:,174) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,85).*STATES(:,37));
    ALGEBRAIC(:,177) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,88).*STATES(:,40));
    ALGEBRAIC(:,179) =  CONSTANTS(:,40).*(exp(ALGEBRAIC(:,177)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp((ALGEBRAIC(:,174)+ CONSTANTS(:,153).*ALGEBRAIC(:,171))./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,175) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,86).*STATES(:,38));
    ALGEBRAIC(:,180) =  CONSTANTS(:,41).*(exp((ALGEBRAIC(:,174)+ CONSTANTS(:,152).*ALGEBRAIC(:,171))./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,175)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,176) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,87).*STATES(:,39));
    ALGEBRAIC(:,181) =  CONSTANTS(:,42).*(exp((ALGEBRAIC(:,175)+ CONSTANTS(:,153).*ALGEBRAIC(:,171))./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,176)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,182) =  CONSTANTS(:,43).*(exp(ALGEBRAIC(:,176)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp((ALGEBRAIC(:,177)+ CONSTANTS(:,152).*ALGEBRAIC(:,171))./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,189) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,101).*STATES(:,22));
    ALGEBRAIC(:,190) = CONSTANTS(:,166)+ALGEBRAIC(:,189);
    ALGEBRAIC(:,199) =  CONSTANTS(:,52).*(exp(CONSTANTS(:,177)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,190)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,200) = ALGEBRAIC(:,199);
    ALGEBRAIC(:,188) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,99).*STATES(:,24));
    ALGEBRAIC(:,191) = CONSTANTS(:,166)+ALGEBRAIC(:,188);
    ALGEBRAIC(:,201) =  CONSTANTS(:,44).*(exp(ALGEBRAIC(:,191)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(CONSTANTS(:,178)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,202) =  - ALGEBRAIC(:,201);
    ALGEBRAIC(:,187) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,100).*STATES(:,23));
    ALGEBRAIC(:,192) = ALGEBRAIC(:,187)+CONSTANTS(:,174);
    ALGEBRAIC(:,203) =  CONSTANTS(:,48).*(exp(CONSTANTS(:,179)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,192)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,205) = ALGEBRAIC(:,203);
    ALGEBRAIC(:,166) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,84).*STATES(:,20));
    ALGEBRAIC(:,178) =  CONSTANTS(:,39).*exp(ALGEBRAIC(:,177)./( CONSTANTS(:,130).*CONSTANTS(:,131))).*(exp(ALGEBRAIC(:,166)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,171)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,185) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,84).*STATES(:,20));
    ALGEBRAIC(:,196) = CONSTANTS(:,175)+ CONSTANTS(:,155).*ALGEBRAIC(:,185);
    ALGEBRAIC(:,212) =  CONSTANTS(:,49).*(exp(CONSTANTS(:,183)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,196)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,220) =  CONSTANTS(:,155).*ALGEBRAIC(:,212);
    ALGEBRAIC(:,219) = ALGEBRAIC(:,214)./CONSTANTS(:,146);
    ALGEBRAIC(:,186) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,98).*STATES(:,21));
    ALGEBRAIC(:,193) = CONSTANTS(:,169)+ALGEBRAIC(:,186);
    ALGEBRAIC(:,206) =  CONSTANTS(:,46).*(exp(ALGEBRAIC(:,193)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(CONSTANTS(:,180)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,195) = CONSTANTS(:,172)+ CONSTANTS(:,156).*ALGEBRAIC(:,186);
    ALGEBRAIC(:,209) =  CONSTANTS(:,47).*(exp(CONSTANTS(:,182)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,195)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,197) = CONSTANTS(:,175)+ CONSTANTS(:,156).*ALGEBRAIC(:,186);
    ALGEBRAIC(:,221) =  CONSTANTS(:,50).*(exp(ALGEBRAIC(:,197)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(CONSTANTS(:,184)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,198) = ALGEBRAIC(:,186)+CONSTANTS(:,173);
    ALGEBRAIC(:,224) =  CONSTANTS(:,51).*(exp(CONSTANTS(:,186)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(ALGEBRAIC(:,198)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,227) = (( CONSTANTS(:,156).*ALGEBRAIC(:,209) - ALGEBRAIC(:,206)) -  CONSTANTS(:,156).*ALGEBRAIC(:,221))+ALGEBRAIC(:,224);
    ALGEBRAIC(:,25) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,53).*STATES(:,2));
    ALGEBRAIC(:,29) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,60).*STATES(:,4));
    ALGEBRAIC(:,34) =  (CONSTANTS(:,147)./( CONSTANTS(:,137).*CONSTANTS(:,138).*CONSTANTS(:,139))).*STATES(:,8).*(STATES(:,43)+CONSTANTS(:,137));
    ALGEBRAIC(:,37) =  (CONSTANTS(:,147)./( CONSTANTS(:,137).*CONSTANTS(:,138).*CONSTANTS(:,139))).*STATES(:,7).*STATES(:,42);
    ALGEBRAIC(:,40) = ALGEBRAIC(:,34)+ALGEBRAIC(:,37);
    ALGEBRAIC(:,43) = ALGEBRAIC(:,40);
    ALGEBRAIC(:,223) =  (( CONSTANTS(:,151).*ALGEBRAIC(:,213))./CONSTANTS(:,137)).*ALGEBRAIC(:,219);
    ALGEBRAIC(:,226) = ALGEBRAIC(:,223);
    ALGEBRAIC(:,230) = ALGEBRAIC(:,43)+ALGEBRAIC(:,226);
    ALGEBRAIC(:,231) =  ALGEBRAIC(:,230).*1000.00;
    ALGEBRAIC(:,232) =  CONSTANTS(:,136).*CONSTANTS(:,161).*ALGEBRAIC(:,231);
    ALGEBRAIC(:,233) =  CONSTANTS(:,1).*(exp((ALGEBRAIC(:,29)+ALGEBRAIC(:,25))./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp((ALGEBRAIC(:,31)+ALGEBRAIC(:,232))./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,164) = (( (CONSTANTS(:,102)).*ALGEBRAIC(:,151)+ CONSTANTS(:,102).*ALGEBRAIC(:,155)+ CONSTANTS(:,102).*ALGEBRAIC(:,147)+ CONSTANTS(:,102).*ALGEBRAIC(:,143)+ CONSTANTS(:,102).*ALGEBRAIC(:,139)+ CONSTANTS(:,102).*ALGEBRAIC(:,158)) - ALGEBRAIC(:,159)) - ALGEBRAIC(:,161);
    ALGEBRAIC(:,183) = (( CONSTANTS(:,153).*ALGEBRAIC(:,179) -  CONSTANTS(:,152).*ALGEBRAIC(:,180)) -  CONSTANTS(:,153).*ALGEBRAIC(:,181))+ CONSTANTS(:,152).*ALGEBRAIC(:,182);
    ALGEBRAIC(:,184) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,60).*STATES(:,4));
    ALGEBRAIC(:,194) = CONSTANTS(:,169)+ CONSTANTS(:,154).*ALGEBRAIC(:,184);
    ALGEBRAIC(:,207) =  CONSTANTS(:,45).*(exp(ALGEBRAIC(:,194)./( CONSTANTS(:,130).*CONSTANTS(:,131))) - exp(CONSTANTS(:,181)./( CONSTANTS(:,130).*CONSTANTS(:,131))));
    ALGEBRAIC(:,210) =   - CONSTANTS(:,154).*ALGEBRAIC(:,207);
    ALGEBRAIC(:,1) = STATES(:,1)./CONSTANTS(:,113);
    ALGEBRAIC(:,3) = STATES(:,12)+STATES(:,14)+STATES(:,17)+STATES(:,16);
    ALGEBRAIC(:,4) = STATES(:,13)+STATES(:,14);
    ALGEBRAIC(:,5) = STATES(:,18)+STATES(:,19);
    ALGEBRAIC(:,6) = STATES(:,10);
    ALGEBRAIC(:,7) = STATES(:,11);
    ALGEBRAIC(:,11) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,70).*STATES(:,31));
    ALGEBRAIC(:,12) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,71).*STATES(:,32));
    ALGEBRAIC(:,13) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,72).*STATES(:,33));
    ALGEBRAIC(:,14) =  CONSTANTS(:,130).*CONSTANTS(:,131).*log( CONSTANTS(:,73).*STATES(:,34));
    ALGEBRAIC(:,15) =  CONSTANTS(:,153).*STATES(:,40)+ CONSTANTS(:,152).*STATES(:,38)+ (CONSTANTS(:,152)+CONSTANTS(:,153)).*STATES(:,39);
    ALGEBRAIC(:,16) = STATES(:,4)./CONSTANTS(:,157);
    ALGEBRAIC(:,17) = STATES(:,20)./CONSTANTS(:,163);
    ALGEBRAIC(:,18) = STATES(:,21)./CONSTANTS(:,167);
    ALGEBRAIC(:,19) = STATES(:,23)./CONSTANTS(:,157);
    ALGEBRAIC(:,20) = STATES(:,24)./CONSTANTS(:,157);
    ALGEBRAIC(:,21) = STATES(:,22)./CONSTANTS(:,157);
    ALGEBRAIC(:,204) = ALGEBRAIC(:,199) - ALGEBRAIC(:,201);
    ALGEBRAIC(:,208) = ALGEBRAIC(:,206);
    ALGEBRAIC(:,211) = ALGEBRAIC(:,201) - ALGEBRAIC(:,207);
    ALGEBRAIC(:,217) = ALGEBRAIC(:,207) - ALGEBRAIC(:,209);
    ALGEBRAIC(:,218) = ALGEBRAIC(:,209) - ALGEBRAIC(:,203);
    ALGEBRAIC(:,222) = ALGEBRAIC(:,203) - ALGEBRAIC(:,212);
    ALGEBRAIC(:,225) = ALGEBRAIC(:,212) - ALGEBRAIC(:,221);
    ALGEBRAIC(:,228) = ALGEBRAIC(:,221) - ALGEBRAIC(:,224);
    ALGEBRAIC(:,229) = ALGEBRAIC(:,224) - ALGEBRAIC(:,199);
end

% Functions required for solving differential algebraic equation
function [CONSTANTS, STATES, ALGEBRAIC] = rootfind_0(VOI, CONSTANTS_IN, STATES_IN, ALGEBRAIC_IN)
    ALGEBRAIC = ALGEBRAIC_IN;
    CONSTANTS = CONSTANTS_IN;
    STATES = STATES_IN;
    global initialGuess_0;
    if (length(initialGuess_0) ~= 4), initialGuess_0 = [0.1,0.1,0.1,0.1];, end
    options = optimset('Display', 'off', 'TolX', 1E-6);
    if length(VOI) == 1
        residualfn = @(algebraicCandidate)residualSN_0(algebraicCandidate, ALGEBRAIC, VOI, CONSTANTS, STATES);
        soln = fsolve(residualfn, initialGuess_0, options);
        initialGuess_0 = soln;
        ALGEBRAIC(:,213) = soln(1);
        ALGEBRAIC(:,214) = soln(2);
        ALGEBRAIC(:,215) = soln(3);
        ALGEBRAIC(:,216) = soln(4);
    else
        SET_ALGEBRAIC(:,213) = logical(1);
        SET_ALGEBRAIC(:,214) = logical(1);
        SET_ALGEBRAIC(:,215) = logical(1);
        SET_ALGEBRAIC(:,216) = logical(1);
        for i=1:length(VOI)
            residualfn = @(algebraicCandidate)residualSN_0(algebraicCandidate, ALGEBRAIC(i,:), VOI(i), CONSTANTS, STATES(i,:));
            soln = fsolve(residualfn, initialGuess_0, options);
            initialGuess_0 = soln;
            TEMP_ALGEBRAIC(:,213) = soln(1);
            TEMP_ALGEBRAIC(:,214) = soln(2);
            TEMP_ALGEBRAIC(:,215) = soln(3);
            TEMP_ALGEBRAIC(:,216) = soln(4);
            ALGEBRAIC(i,SET_ALGEBRAIC) = TEMP_ALGEBRAIC(SET_ALGEBRAIC);
        end
    end
end

function resid = residualSN_0(algebraicCandidate, ALGEBRAIC, VOI, CONSTANTS, STATES)
    ALGEBRAIC(:,213) = algebraicCandidate(1);
    ALGEBRAIC(:,214) = algebraicCandidate(2);
    ALGEBRAIC(:,215) = algebraicCandidate(3);
    ALGEBRAIC(:,216) = algebraicCandidate(4);
    resid(1) = ALGEBRAIC(:,213) - piecewise({ALGEBRAIC(:,214)>0.00000, CONSTANTS(:,148) }, CONSTANTS(:,149));
    resid(2) = ALGEBRAIC(:,215) -  (CONSTANTS(:,150)./ALGEBRAIC(:,213)).*STATES(:,44).*CONSTANTS(:,146);
    resid(3) = ALGEBRAIC(:,216) -  (CONSTANTS(:,150)./ALGEBRAIC(:,213)).*(STATES(:,41) - CONSTANTS(:,137)).*CONSTANTS(:,146);
    resid(4) = ALGEBRAIC(:,214) - ( - ALGEBRAIC(:,215)+ALGEBRAIC(:,216));
end

% Compute result of a piecewise function
function x = piecewise(cases, default)
    set = [0];
    for i = 1:2:length(cases)
        if (length(cases{i+1}) == 1)
            x(cases{i} & ~set,:) = cases{i+1};
        else
            x(cases{i} & ~set,:) = cases{i+1}(cases{i} & ~set);
        end
        set = set | cases{i};
        if(set), break, end
    end
    if (length(default) == 1)
        x(~set,:) = default;
    else
        x(~set,:) = default(~set);
    end
end

% Pad out or shorten strings to a set length
function strout = strpad(strin)
    req_length = 160;
    insize = size(strin,2);
    if insize > req_length
        strout = strin(1:req_length);
    else
        strout = [strin, blanks(req_length - insize)];
    end
end

